********************************************************************************************
******** Uncertainty measures from partially rounded probabilistic forecast surveys ********
********************************************************************************************
set type double

****************************************
******** Euro area realizations ********
****************************************
cd "SET WORKING DIRECTLY TO RAW-FOLDER"

******** HICP inflation vintage data ********
* Link: https://sdw.ecb.europa.eu/quickview.do?SERIES_KEY=194.RTD.M.S0.N.P_C_OV.X

* download data
*copy "https://sdw.ecb.europa.eu/export.do?history=true&historyDays=10000&node=HISTORYVINTAGE&SERIES_KEY=194.RTD.M.S0.N.P_C_OV.X&seriesId=194.RTD.M.S0.N.P_C_OV.X&exportType=csv" "ecb_rtd_inflation.csv", replace

* prepare data
insheet using "ecb_rtd_inflation.csv", delim(,) clear
drop in 1/3
rename v1 target_period

* new variables
gen target_year=substr(target_period,1,4)
gen target_month=substr(target_period,5,3)
replace target_month="1" if target_month=="Jan"
replace target_month="2" if target_month=="Feb"
replace target_month="3" if target_month=="Mar"
replace target_month="4" if target_month=="Apr"
replace target_month="5" if target_month=="May"
replace target_month="6" if target_month=="Jun"
replace target_month="7" if target_month=="Jul"
replace target_month="8" if target_month=="Aug"
replace target_month="9" if target_month=="Sep"
replace target_month="10" if target_month=="Oct"
replace target_month="11" if target_month=="Nov"
replace target_month="12" if target_month=="Dec"
destring target_year target_month, replace
egen t=group(target_year target_month)
sort t
gen fr=.
gen sr=.
gen i=_n
order target_period target_year target_month t i fr

* replace commas and missing values
foreach v of varlist v*{
	replace `v'=subinstr(`v',",",".",.)
	replace `v'="." if `v'=="x"
}
destring _all, replace

* for each vintage, calculate annual averages for vintages with releases for all 12 months
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==12, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* annual growth rate rate is the annual average over annual average percentage change
foreach v of varlist v*{
	gen `v'_gr=100*((`v'/l.`v')-1)
	drop `v'
}

* count number of variables (subtract 6 to get number of releases) and loop through rows  
qui des
local max=r(k)-6
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=2(1)`max'{
		replace fr=v`j'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=2(1)`max'{
		local k=`j'-1
		cap noisily: replace sr=v`k'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
}

* current release
rename v2_mean_gr cr

* save data
gen variable="inflation"
keep if target_year>=1999
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "ecb_rtd_inflation.dta", replace

******** Unemployment rate vintage data ********
* Link: https://sdw.ecb.europa.eu/quickview.do?SERIES_KEY=194.RTD.M.S0.S.L_UNETO.F

* download data
*copy "https://sdw.ecb.europa.eu/export.do?history=true&historyDays=10000&node=HISTORYVINTAGE&SERIES_KEY=194.RTD.M.S0.S.L_UNETO.F&seriesId=194.RTD.M.S0.S.L_UNETO.F&exportType=csv" "ecb_rtd_unemployment.csv", replace

* prepare data
insheet using "ecb_rtd_unemployment.csv", delim(,) clear
drop in 1/3
rename v1 target_period

* new variables
gen target_year=substr(target_period,1,4)
gen target_month=substr(target_period,5,3)
replace target_month="1" if target_month=="Jan"
replace target_month="2" if target_month=="Feb"
replace target_month="3" if target_month=="Mar"
replace target_month="4" if target_month=="Apr"
replace target_month="5" if target_month=="May"
replace target_month="6" if target_month=="Jun"
replace target_month="7" if target_month=="Jul"
replace target_month="8" if target_month=="Aug"
replace target_month="9" if target_month=="Sep"
replace target_month="10" if target_month=="Oct"
replace target_month="11" if target_month=="Nov"
replace target_month="12" if target_month=="Dec"
destring target_year target_month, replace
egen t=group(target_year target_month)
sort t
gen fr=.
gen sr=.
gen i=_n
order target_period target_year target_month t i fr

* replace commas and missing values
foreach v of varlist v*{
	replace `v'=subinstr(`v',",",".",.)
	replace `v'="." if `v'=="x"
}
destring _all, replace

* for each vintage, calculate annual averages for vintages with releases for all 12 months
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==12, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* count number of variables (subtract 6 to get number of releases) and loop through rows  
qui des
local max=r(k)-6
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=2(1)`max'{
		replace fr=v`j'_mean in `i' if v`j'_mean[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=2(1)`max'{
		local k=`j'-1
		cap noisily: replace sr=v`k'_mean in `i' if v`j'_mean[`i']!=.
	}
}

* current release
rename v2_mean cr

* save data
gen variable="unemployment"
keep if target_year>=1999
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "ecb_rtd_unemployment.dta", replace

******** Real GDP vintage data ********
* Link: https://sdw.ecb.europa.eu/quickview.do?SERIES_KEY=194.RTD.Q.S0.S.G_GDPM_TO_C.E&start=&end=&submitOptions.x=0&submitOptions.y=0&trans=YPC

* download data
*copy "https://sdw.ecb.europa.eu/export.do?history=true&historyDays=10000&node=HISTORYVINTAGE&SERIES_KEY=194.RTD.Q.S0.S.G_GDPM_TO_C.E&seriesId=194.RTD.Q.S0.S.G_GDPM_TO_C.E&exportType=csv" "ecb_rtd_growth.csv", replace

* prepare data
insheet using "ecb_rtd_growth.csv", delim(,) clear
drop in 1/3
rename v1 target_period

* new variables
gen target_year=substr(target_period,1,4)
gen target_quarter=substr(target_period,6,1)
destring target_year target_quarter, replace
egen t=group(target_year target_quarter)
sort t
gen fr=.
gen sr=.
gen i=_n
order target_period target_year target_quarter t i fr

* replace commas and missing values
foreach v of varlist v*{
	replace `v'=subinstr(`v',",",".",.)
	replace `v'="." if `v'=="x"
}
destring _all, replace

* for each vintage, calculate annual averages for vintages with releases for all 4 quarters
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==4, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* annual growth rate rate is the annual average over annual average percentage change
foreach v of varlist v*{
	gen `v'_gr=100*((`v'/l.`v')-1)
	drop `v'
}

* count number of variables (subtract 6 to get number of releases) and loop through rows  
qui des
local max=r(k)-6
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=2(1)`max'{
		replace fr=v`j'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=2(1)`max'{
		local k=`j'-1
		cap noisily: replace sr=v`k'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
}

* current release
rename v2_mean cr

* save data
gen variable="growth"
keep if target_year>=1999
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "ecb_rtd_growth.dta", replace

******** append data sets ********
append using "ecb_rtd_inflation.dta"
append using "ecb_rtd_unemployment.dta"
gen type="fe"
saveold "../Processed\euro_actual.dta", replace
cap noisily: erase "ecb_rtd_growth.dta"
cap noisily: erase "ecb_rtd_inflation.dta"
cap noisily: erase "ecb_rtd_unemployment.dta"

********************************************************
******** ECB Survey of Professional Forecasters ********
********************************************************
* REMARK: The code below can be used to download the individual responses from all SPF rounds up until the most recent release. Note, however, that the data retroactively includes core inflation forecasts from 2016Q4 
* onwards, which are NOT accounted for below (those were not included when we first downloaded the SPF data). Also, the code does NOT take care of the introduction of bins for GDP growth with a width of two percentage 
* points in 2020Q2. Thus, if you want to update our results, you first need to adjust the code to account for these two factors.

* download .csv files from ECB website and unzip
/*
copy http://www.ecb.europa.eu/stats/prices/indic/forecast/shared/files/SPF_individual_forecasts.zip SPF.zip, replace
unzipfile SPF.zip, replace
erase "SPF.zip"

* identify current year for automatic insheet
clear
set obs 1
local date "$S_DATE"
gen date="`date'"
gen year=substr(date,-4,4)
destring year, replace
qui sum year
local now=r(mean)
clear
			
* loop over all years and quarters to insheet .csv files
forvalues year=1999/`now'{
	forvalues quarter=1/4{
		capture noisily insheet using "`year'Q`quarter'.csv", comma clear
		
		* execute the following commands for all existing survey rounds (return code is zero in that case)
		if _rc==0{
		
			* forecast period 
			qui gen fct_period="`year'q`quarter'"
			qui gen fct_year=`year'
			qui gen fct_quarter=`quarter'	
		
			* rename variables
			rename v1 target_period
			rename v2 fct_source
			rename v3 point

			* identify forecasts for different variables (inflation, GDP, unemployment, assumptions)
			gen Variable="inflation" if target_p=="INFLATION EXPECTATIONS; YEAR-ON-YEAR CHANGE IN HICP"
			replace Variable="growth" if target_p=="GROWTH EXPECTATIONS; YEAR-ON-YEAR CHANGE IN REAL GDP"
			replace Variable="unemployment" if target_p=="EXPECTED UNEMPLOYMENT RATE; PERCENTAGE OF LABOUR FORCE"
			replace Variable="assumptions" if target_p=="ASSUMPTIONS"
			carryforward Variable, replace
			
			* drop lines with variables description and empty lines
			drop if target_p=="INFLATION EXPECTATIONS; YEAR-ON-YEAR CHANGE IN HICP"
			drop if target_p=="GROWTH EXPECTATIONS; YEAR-ON-YEAR CHANGE IN REAL GDP"
			drop if target_p=="EXPECTED UNEMPLOYMENT RATE; PERCENTAGE OF LABOUR FORCE"
			drop if target_p==""
			drop if Variable=="assumptions"

			* generate indicator for forecast type (fixed horizon vs. fixed event)
			gen type="fh"
			replace type="fe" if strlen(target_p)==4
			
			* replaces upper-case by lower-case letters
			replace target_period=lower(target_p)
			
			* decompose target period into target year and target month/quarter
			gen target_year=substr(target_p,1,4) if strlen(target_p)<13
			gen target_quarter=substr(target_p,5,3) if strlen(target_p)<13
			
				* fixed event (forecasts are made for end of year)
				replace target_q="4" if type=="fe"&strlen(target_p)<13
			
				* fixed horizon (transform target months into target quarters)
				replace target_q="1" if target_q=="jan"|target_q=="feb"|target_q=="mar"|target_q=="q1"
				replace target_q="2" if target_q=="apr"|target_q=="may"|target_q=="jun"|target_q=="q2"
				replace target_q="3" if target_q=="jul"|target_q=="aug"|target_q=="sep"|target_q=="q3"
				replace target_q="4" if target_q=="oct"|target_q=="nov"|target_q=="dec"|target_q=="q4"
			
				* destring target year and target quarter
				destring target_y target_q, replace
			
			* generate horizon variable (appropriate as it is for fixed event)
			gen h=4*(target_y-fct_y)+(target_q-fct_q)+1
			
				* fixed horizon 
				replace h=4 if type=="fh"&h<=4
				replace h=8 if type=="fh"&h>4&h<=8
				replace h=20 if type=="fh"&h>8
			
			* generate target variable
			gen target=.
			replace target=1 if type=="fh"&h==4
			replace target=2 if type=="fh"&h==8
			replace target=3 if type=="fh"&h==20
			replace target=4 if type=="fe"&h<=4
			replace target=5 if type=="fe"&h>4&h<=8
			replace target=6 if type=="fe"&h>8&h<=12
			replace target=7 if type=="fe"&h>12
			order Variable fct_p fct_y fct_q target_p target_y target_q type h target fct_s point v*

			* only look at a variable a time in order to properly name the bins
			foreach v in inflation growth unemployment{
			preserve
			keep if Variable=="`v'"
			
			* drop empty bins and rename the remaining ones according to description in first line
			foreach x of varlist v*{
				if `x'[1]==""{
					drop `x'
				}
				else{
					local y=`x'[1]
					rename `x' `y' 
				}
			}
			
			* label and rename lower open intervals including zero (rule below does not apply here)
			cap noisily rename TN0_5 FN1_0
			cap noisily rename T0_0 FN0_5
			cap noisily rename T0_5 F0_0
						
			* label and rename upper open intervals including zero (rule below does not apply here)
			cap noisily rename FN0_5 FN0_5
			cap noisily rename F0_0 F0_0
			cap noisily rename F0_5 F0_5
			
			* label and rename the remaining open intervals 
			forvalues i=1(1)20{
				local j=`i'-1
				local k=`i'+1
				
				* lower open intervals
				* i.e. TN1_5 => FN2_0TN1_6
				cap noisily rename TN`i'_5 FN`i'_0
				* i.e. TN1_0 => FN1_5TN1_1
				cap noisily rename TN`i'_0 FN`i'_5
				* i.e. T1_0 => F0_5T0_9
				cap noisily rename T`i'_0 F`j'_5
				* i.e. T1_5 => F1_0T1_4
				cap noisily rename T`i'_5 F`i'_0
				
				* upper open intervals
				* i.e. F1_0 => F1_0T1_4
				cap noisily rename F`i'_0 F`i'_0
				* i.e. F1_5 => F1_5T1_9
				cap noisily rename F`i'_5 F`i'_5
				* i.e. FN1_0 => FN1_0TN0_6 (should not exist)
				cap noisily rename FN`i'_0 FN`i'_0
				* i.e. FN1_5 => FN1_5TN1_1 (should not exist)
				cap noisily rename FN`i'_5 FN`i'_5			
			}
			
			* determine the smallest and largest bin (so the rest can be dropped later)
			foreach x of varlist F*{
				gen varname_`x'="`x'"
				replace varname_`x'=substr(varname_`x',2,10)
				if substr(varname_`x',1,1)=="N"{
					gen minus_`x'="-"
					replace varname_`x'=substr(varname_`x',2,10)
					egen varname_`x'2=concat(minus_`x' varname_`x')
					drop varname_`x' minus_`x'
					rename varname_`x'2 varname_`x'
				}
				replace varname_`x'=subinstr(varname_`x', "_", ".",.) 
				destring varname_`x', replace
			}
			egen double lower_min=rowmin(varname*)
			egen double lower_max=rowmax(varname*)
			drop varname*
			
			* drop remaining extra lines, destring and save
			drop if target_p=="target_period"
			destring fct_s point F*, replace
			saveold "`year'Q`quarter'_`v'.dta", replace
			restore
		
			}
		}
	}
}

* append data for different variables and survey periods
clear
foreach v in inflation growth unemployment{
	forvalues year=1999/`now'{
		forvalues quarter=1/4{
			cap noisily append using "`year'Q`quarter'_`v'.dta"
			if _rc==0{
				erase "`year'Q`quarter'_`v'.dta"
			}
		}
	}
}
encode fct_p, gen(t)
rename Variable variable
order variable t fct_p fct_y fct_q target_p target_y target_q type h target fct_s point lower*
saveold "../Processed\euro_spf.dta", replace
*/

******************************
******** process data ********
******************************
cd "../"
use "Processed\euro_spf.dta", clear

* drop five-year fixed horizon forecasts (only available in 1999Q1, 2000Q1 and 2001Q1)
drop if target==3

* reshape into long format for each id, so that probabilities are in one column
egen id=group(variable fct_p target fct_s)
reshape long F, i(id) j(binn) string
rename F p

**** split bin names and generate lower and upper bound of bin 
split binn, p("_")
replace binn1=subinstr(binn1,"N","-",.)
gen miss=.
egen lower=concat(binn1 miss binn2)
drop binn binn1 binn2 miss
destring lower, replace
gen double upper=lower+0.4

* extend lower and upper end of interior bins by 0.05 percentage points
replace lower=lower-0.05
replace upper=upper+0.05
replace lower_min=lower_min-0.05
replace lower_max=lower_max-0.05

* group variable for bins
egen binn=group(lower)
sort id binn

* calculate number of bins used
bys id: egen nbins=count(p) if p!=0&p!=.

* calculate total probability mass and drop if forecasters do not report a density forecast or reported probabilities do not sum to one as in Abel et al. (2016)
bys id: egen pmasstotal=sum(p), missing
drop if pmasstotal==.|pmasstotal<=99.1|pmasstotal>=100.9

* replace unused bins of forecasters that report density forecasts with zeroes
replace p=0 if p==.

* merge realizations
merge m:m variable type target_year using "Processed\euro_actual.dta" 
drop if _merge==2
drop _merge
sort id binn

* drop bins not available 
keep if lower>=lower_min&lower<=lower_max

******** examples of histogram forecasts ********

**** Figure 1: Two examples of histogram forecasts for the inflation rate from the ECB-SPF (Example A)
preserve
keep if variable=="inflation"&target_year==2016&h==1&fct_source==102
replace p=. if p==0
graph bar p, bar(1, color(red)) over(binn, label(angle(90)) relabel(1 "[-1.5,-1.1]" 2 "[-1.0,-0.6]" 3 "[-0.5,-0.1]" 4 "[0.0,0.4]" 5 "[0.5,0.9]" 6 "[1.0,1.4]" 7 "[1.5,1.9]" 8 "[2.0,2.4]" 9 "[2.5,2.9]" 10 "[3.0,3.4]" 11 "[3.5,3.9]" 12 "[4.0,4.4]")) legend(off) title("") legend(off) ytitle("Probability") ytick(70, noticks) ylabel(none) scheme(s2color) plotr(m(zero)) blabel(total, format(%9.0f)) graphregion(color(white)) bgcolor(white)
graph export "Figures\euro_rounder_example.pdf", replace
gen double midpoint=lower+(upper-lower)/2
replace p=p/100
egen point_imp=total(midpoint*p) 
egen variance=total((midpoint-point_imp)^2*p)
qui sum variance
dis "Histogram variance of rounder = "r(mean)
restore

**** Figure 1: Two examples of histogram forecasts for the inflation rate from the ECB-SPF (Example B)
preserve
keep if variable=="inflation"&target_year==2016&h==1&fct_source==95
replace p=. if p==0
graph bar p, bar(1, color(red)) over(binn, label(angle(90)) relabel(1 "[-1.5,-1.1]" 2 "[-1.0,-0.6]" 3 "[-0.5,-0.1]" 4 "[0.0,0.4]" 5 "[0.5,0.9]" 6 "[1.0,1.4]" 7 "[1.5,1.9]" 8 "[2.0,2.4]" 9 "[2.5,2.9]" 10 "[3.0,3.4]" 11 "[3.5,3.9]" 12 "[4.0,4.4]")) legend(off) title("") legend(off) ytitle("Probability") ytick(25, noticks) ylabel(none) scheme(s2color) plotr(m(zero)) blabel(total, format(%9.3f)) graphregion(color(white)) bgcolor(white)
graph export "Figures\euro_nonrounder_example.pdf", replace
gen double midpoint=lower+(upper-lower)/2
replace p=p/100
egen point_imp=total(midpoint*p) 
egen variance=total((midpoint-point_imp)^2*p)
qui sum variance
dis "Histogram variance of non-rounder = "r(mean)
local before=r(mean)
restore
    
******** density forecast performance ********

* indicator for realization (be careful if realization outside available bins)
gen ind=0 if type=="fe"&fr!=.
replace ind=1 if type=="fe"&fr>=lower&fr<=upper
replace ind=1 if type=="fe"&fr!=.&fr<lower_min&lower==lower_min
replace ind=1 if type=="fe"&fr!=.&fr>lower_max+0.5&lower==lower_max

* qps score
bys id: egen qps=total((p/100-ind)^2) if fr!=.

* rps score 
bys id: gen cdf=sum(p)/100
bys id: gen cdf_ind=sum(ind) if ind!=.
bys id: egen rps=total((cdf-cdf_ind)^2) if fr!=.
drop cdf* ind*

******** rounding schemes ********

* if left-most (right-most) bin is exterior, set bound one percentage point below (above) the right (left) endpoint of the lowest (highest) bin during the survey history 
* in other words, assume open intervals have twice the length of the other intervals
replace lower=upper-1 if lower==lower_min
replace upper=lower+1 if lower==lower_max

* fix bounds of individual densities at left-most/right-most bin with non-zero probability
drop if p==0

* point forecast (note that float has higher precision but trims extreme decimal places)
gen float point100=100*point
gen float point_m01=(int(point100/10)*10)==point100 if point!=.
replace point_m01=1-point_m01
gen float point_m05=(int(point100/50)*50)==point100 if point!=.
replace point_m05=1-point_m05
drop point100

* integer-based: probabilities multiple of tau (note that float has higher precision but trims extreme decimal places)
gen float p2=p
forvalues tau=1(1)10{
	gen mult`tau'=(int(p2/`tau')*`tau')==p2 if p2!=0
	replace mult`tau'=0 if mult`tau'==.
	bys id: egen bin_m`tau'=mode(mult`tau'), min
	replace bin_m`tau'=1-bin_m`tau'
}
drop p2

* count number of decimals of each probability number
tostring p, replace force
split p, p(.)
gen d=0
replace d=strlen(p2)
bys id: egen d_avg=mean(d)

**** Figure 2: Relative frequencies of the number of decimals reported in the SPF
preserve
keep if target==4|target==5
keep if target_year>=2000&target_year<=2017
gen v=1 if variable=="inflation"
replace v=2 if variable=="growth"
replace v=3 if variable=="unemployment"
* number of probabilities per variable
gen prob=1
egen count_all=total(prob), by(v)
* number of probabilities per variable and digit
gen prob_dec=1 if d>0
egen count_d_each=total(prob_dec) if d>0, by(v d)
* share
gen share_all=100*(count_d_each/count_all)
graph bar (mean) share_all if d>0, over(v, gap(5)) asyvar bar(1, color(red)) bar(2, color(dkgreen)) bar(3, color(dknavy)) over(d, label(labsize(small))) title("") ytitle("%", orientation(horizontal) size(small)) ytick(0(1)7) ylabel(0(1)7, angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) plotr(m(zero)) legend(off)
graph export "Figures\euro_decimals_share.pdf", replace
restore

* decimal-based: any, most or all probabilities contain decimals
gen bin_dec=d>0 
bys id: egen nbins_dec=total(bin_dec) 
gen rho=nbins_dec/nbins
gen bin_any=rho>0
gen bin_most=rho>0.5
gen bin_all=rho==1
destring p, replace
drop mult* p1 p2 d bin_dec nbins_dec rho

******** histogram moments ********

* bin midpoint
gen double midpoint=lower+(upper-lower)/2

* histogram mean 
replace p=p/100
bys id: egen point_imp=total(midpoint*p) 

* forecast errors	
gen err=fr-point_imp 
gen sqerr=(fr-point_imp)^2 
gen abserr=abs(fr-point_imp) 

* histogram variance
bys id: egen variance=total((midpoint-point_imp)^2*p)

* skewness
bys id: egen skew=total((midpoint-point_imp)^3*p) if nbins>1
replace skew=skew/variance^(3/2)

* kurtosis 
bys id: egen kurt=total((midpoint-point_imp)^4*p) if nbins>1
replace kurt=kurt/variance^(4/2)

******** beta distributions ********
sort id binn
bys id: gen F=100*sum(p)
foreach x in a b l r c point_beta variance_beta{
	qui gen `x'=.
}

levelsof variable, clean local(vlist)
foreach v of local vlist{
	levelsof id if variable=="`v'"&target==4|variable=="`v'"&target==5, clean local(idlist)
	foreach id of local idlist{
	
		**** support of Beta distribution
		dis "id = "`id'
		qui sum lower if id==`id'
		local l=`r(min)'
		qui sum upper if id==`id'
		local r=`r(max)'
		qui sum nbins if id==`id'
		
		**** No bins used (redundant)
		if r(N)==0{
			dis "No observations"
		}
		
		**** all other cases (triangle over one or two bins, beta distribution over more than two)
		else{
		
			**** Case 1: triangle distribution over one bin
			if r(mean)==1{
				local c		         		= (`l'+`r')/2
				replace l  	         		= `l' if id==`id'
				replace r            		= `r' if id==`id'
				replace c	         		= `c' if id==`id'
				replace point_beta   		= `c' if id==`id'
				replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
			}	
			
			**** Case 2: triangle distribution over two bins
			else if r(mean)==2{
				
				* determine boundary between both bins
				qui sum upper if id==`id'
				local m=r(min)
				
				* determine probability mass in both bins
				qui sum F if id==`id'
				local p_l=r(min)/100
				local p_r=1-`p_l'
				
				**** Case 2a: lower bin contains more probability mass
				if `p_l'>=.5{
					local r 	         		= `m'+((`m'-`l')*sqrt(.5*`p_r'))/(1-sqrt(.5*`p_r'))
					local c		         		= (`l'+`r')/2
					replace l            		= `l' if id==`id'
					replace r           		= `r' if id==`id'
					replace point_beta   		= (`l'+`c'+`r')/3 if id==`id'
					replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
				}
				
				**** Case 2b: upper bin contains more probability mass
				else{
					local l 	         		= `m'-((`r'-`m')*sqrt(.5*`p_l'))/(1-sqrt(.5*`p_l'))
					local c		         		= (`l'+`r')/2
					replace l            		= `l' if id==`id'
					replace r            		= `r' if id==`id'	
					replace point_beta   		= (`l'+`c'+`r')/3 if id==`id'
					replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
				}
			}
			
			**** Case 3: generalized beta distribution over more than two bins
			else{
				qui nl (F=100*ibeta({a},{b},(upper-`l')/(`r'-`l'))) if id==`id', initial(a 2 b 2) nolog 
				mat tempb = e(b)
				svmat double tempb
				replace a          		  = tempb1[1] if id==`id'
				replace b          		  = tempb2[1] if id==`id'
				drop temp*
				replace l          		  = `l' if id==`id'
				replace r          		  = `r' if id==`id'	
				replace point_beta 		  = a/(a+b)*(`r'-`l')+`l' if id==`id'
				replace variance_beta     = a*b/((a+b+1)*(a+b)^2)*(`r'-`l')^2 if id==`id'
			}
		}
	}
}
saveold "Processed\euro_spf_processed.dta", replace

******** prepare to reshape and rearrange data ********
use "Processed\euro_spf_processed.dta", clear

* suffix to be added to variables in wide format
gen suffix="_g"
replace suffix="_i" if variable=="inflation"
replace suffix="_u" if variable=="unemployment"

* drop duplicates of each id 
duplicates drop id, force
drop variable p lower* upper midpoint binn pmasstotal id F a b l r c

* share of predictions with one bin (FN 11)
preserve
keep if target==4|target==5
keep if target_year>=2000&target_year<=2017
count if nbins==1
local onebin=r(N)
count  
local all=r(N)
dis "Share of histograms with one bin = "100*(`onebin'/`all')
restore

******** share of non-rounded fixed-horizon forecasts in 2008Q4 and 2013Q2 (discussed in Section 5.1) ********
preserve
keep if target==1|target==2|target==7

* 2008Q3
egen non_rounders=total(bin_m5) if t==39, by(suffix target)
egen total=count(bin_m5) if t==39, by(suffix target)
gen fraction=100*(non_rounders/total)
gen rounders=100-fraction
egen id=group(suffix target)
replace id=id+3 if suffix=="_g"
replace id=id-3 if suffix=="_i"
graph bar rounders fraction, over(id, label(labsize(small)) relabel(1 "h=4" 2 "h=8" 3 "h=20" 4 "h=4" 5 "h=8" 6 "h=20" 7 "h=4" 8 "h=8" 9 "h=20")) text(-14 17 "Inflation") text(-14 50 "Growth") text(-14 84 "Unemployment") stack title("2008Q3, m5") ylabel(, angle(horizontal)) ytitle("") scale(1.5) scheme(s1color) legend(off) plotr(m(zero)) bar(1,color(/*dknavy*/gs8)) bar(2,color(/*eltblue*/orange_red)) b1title(" ")
bys suffix target: sum rounders if t==39
drop non_rounders total fraction rounders id

* 2013Q2
egen non_rounders=total(bin_m5) if t==58, by(suffix target)
egen total=count(bin_m5) if t==58, by(suffix target)
gen fraction=100*(non_rounders/total)
gen rounders=100-fraction
egen id=group(suffix target)
replace id=id+3 if suffix=="_g"
replace id=id-3 if suffix=="_i"
graph bar rounders fraction, over(id, label(labsize(small)) relabel(1 "h=4" 2 "h=8" 3 "h=20" 4 "h=4" 5 "h=8" 6 "h=20" 7 "h=4" 8 "h=8" 9 "h=20")) text(-14 17 "Inflation") text(-14 50 "Growth") text(-14 84 "Unemployment") stack title("2013Q2, m5") ylabel(, angle(horizontal)) ytitle("") scale(1.5) scheme(s1color) legend(off) plotr(m(zero)) bar(1,color(/*dknavy*/gs8)) bar(2,color(/*eltblue*/orange_red)) b1title(" ")
bys suffix target: sum rounders if t==58
restore

******** reshape and rearrange data ********
egen id=group(fct_p target fct_source)
drop target
sort id suffix 
reshape wide target* cr sr fr point* qps rps nbins bin_* d_avg *err variance* skew kurt, i(id) j(suffix) string
drop id

* new target variable
gen target=.
replace target=1 if type=="fh"&h==4
replace target=2 if type=="fh"&h==8
replace target=3 if type=="fh"&h==20
replace target=4 if type=="fe"&h<=4
replace target=5 if type=="fe"&h>4&h<=8
replace target=6 if type=="fe"&h>8&h<=12
replace target=7 if type=="fe"&h>12

* in the following, focus on this year and next year fixed event forecasts
keep if target==4|target==5

* check for which target years realizations are available
keep if target_year_g>=2000&target_year_g<=2017

* additional variables
foreach x in g i u{

	* average point forecast 
	bys t target: egen point_avg_`x'=mean(point_imp_`x')

	* disagreement (variance)
	gen dev_`x'=(point_imp_`x'-point_avg_`x')^2
	bys t target: egen participants_`x'=count(point_imp_`x')
	bys t target: egen sum_`x'=total(dev_`x') if participants_`x'>0
	gen disagreement_`x'=(1/(participants_`x'-1))*sum_`x'
	drop dev_`x' participants_`x' sum_`x'	

	* average uncertainty
	bys t target: egen ubar_`x'=mean(variance_`x')
	bys t target: egen ubar_`x'_rou=mean(variance_`x') if bin_m5_`x'==0
	bys t target: egen ubar_`x'_non=mean(variance_`x') if bin_m5_`x'==1

}

* order and save data
order t fct_period fct_year fct_quarter type h target fct_source target_period_g target_year_g target_quarter_g fr_g sr_g cr_g point_g point_m01_g point_m05_g nbins_g d_avg_g bin_m1_g-bin_m10_g bin_any_g bin_most_g bin_all_g point_imp_g err_g abserr_g sqerr_g variance_g skew_g kurt_g qps_g rps_g point_beta_g variance_beta_g point_avg_g disagreement_g ubar_g* target_period_i target_year_i target_quarter_i fr_i sr_i cr_i point_i point_m01_i point_m05_i nbins_i d_avg_i bin_m1_i-bin_m10_i bin_any_i bin_most_i bin_all_i point_imp_i err_i abserr_i sqerr_i variance_i skew_i kurt_i qps_i rps_i point_beta_i variance_beta_i point_avg_i disagreement_i ubar_i* target_period_u target_year_u target_quarter_u fr_u sr_u cr_u point_u point_m01_u point_m05_u nbins_u d_avg_u bin_m1_u-bin_m10_u bin_any_u bin_most_u bin_all_u point_imp_u err_u abserr_u sqerr_u variance_u skew_u kurt_u qps_u rps_u point_beta_u variance_beta_u point_avg_u disagreement_u ubar_u*
sort t target fct_source
saveold "Processed\euro_spf_processed.dta", replace

**********************************
******** USA realizations ********
**********************************
cd "Raw"

******** Inflation vintage data (Percentage change (annual average over annual average) in the chain-weighted GDP price index) ********
* Link: https://www.philadelphiafed.org/research-and-data/real-time-center/real-time-data/data-files/p

* download data (quarterly vintages)
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/real-time-data/data-files/files/xlsx/pqvqd.xlsx "fed_rtd_inflation.xlsx", replace

* prepare data
import excel using "fed_rtd_inflation.xlsx", first sheet("P") clear
rename DATE target_period

* new variables
gen target_year=substr(target_period,1,4)
gen fr=.
gen sr=.
gen i=_n
order target_period target_year i fr

* rename the vintages
local l=1
foreach v of varlist P*{
	rename `v' v`l'
	local l=`l'+1
}

* replace missing values
foreach v of varlist v*{
	cap noisily: replace `v'="." if `v'=="#N/A"
}
destring _all, replace
drop if target_year==.

* for each vintage, calculate annual averages for vintages with releases for all 4 quarters
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==4, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* annual growth rate rate is the annual average over annual average percentage change
foreach v of varlist v*{
	gen `v'_gr=100*((`v'/l.`v')-1)
	drop `v'
}

* count number of variables (subtract 5 to get number of releases) and loop through rows  
qui des 
local max=r(k)-5
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=`max'(-1)1{
		replace fr=v`j'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=`max'(-1)1{
		local k=`j'+1
		cap noisily: replace sr=v`k'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}	
}

* current release
rename v`max' cr

* save data
gen variable="inflation"
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "fed_rtd_inflation.dta", replace

******** Unemployment rate vintage data (Annual average of the civilian unemployment rate) ********
* Link: https://www.philadelphiafed.org/research-and-data/real-time-center/real-time-data/data-files/ruc

* download data (quarterly vintages and monthly observations)
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/real-time-data/data-files/files/xlsx/rucqvmd.xlsx "fed_rtd_unemployment.xlsx", replace

* prepare data
import excel using "fed_rtd_unemployment.xlsx", first sheet("ruc") clear
rename DATE target_period

* new variables
gen target_year=substr(target_period,1,4)
gen fr=.
gen sr=.
gen i=_n
order target_period target_year i fr

* rename the vintages
local l=1
foreach v of varlist RUC*{
	rename `v' v`l'
	local l=`l'+1
}

* replace missing values
foreach v of varlist v*{
	cap noisily: replace `v'="." if `v'=="#N/A"
}
destring _all, replace
drop if target_year==.

* for each vintage, calculate annual averages for vintages with releases for all 12 months
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==12, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* count number of variables (subtract 5 to get number of releases) and loop through rows  
qui des 
local max=r(k)-5
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=`max'(-1)1{
		replace fr=v`j'_mean in `i' if v`j'_mean[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=`max'(-1)1{
		local k=`j'+1
		cap noisily: replace sr=v`k'_mean in `i' if v`j'_mean[`i']!=.
	}	
}

* current release
rename v`max' cr

* save data
gen variable="unemployment"
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "fed_rtd_unemployment.dta", replace

******** Real GDP vintage data (Percentage change (annual average over annual average) in chain-weighted real GDP) ********
* Link: https://www.philadelphiafed.org/research-and-data/real-time-center/real-time-data/data-files/routput

* download data (quarterly vintages)
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/real-time-data/data-files/files/xlsx/routputmvqd.xlsx "fed_rtd_growth.xlsx", replace

* prepare data 
import excel using "fed_rtd_growth.xlsx", first sheet("ROUTPUT") clear
rename DATE target_period

* new variables
gen target_year=substr(target_period,1,4)
gen fr=.
gen sr=.
gen i=_n
order target_period target_year i fr

* rename the vintages
local l=1
foreach v of varlist ROUTPUT*{
	rename `v' v`l'
	local l=`l'+1
}

* replace missing values
foreach v of varlist v*{
	cap noisily: replace `v'="." if `v'=="#N/A"
}
destring _all, replace
drop if target_year==.

* for each vintage, calculate annual averages for vintages with releases for all 4 quarters
foreach v of varlist v*{
	egen `v'_count=count(`v') if `v'!=.&`v'!=0, by(target_year)
	egen `v'_mean=mean(`v') if `v'_count==4, by(target_year)
	drop `v' `v'_count
}
duplicates drop target_year, force
tset target_year
replace i=_n

* annual growth rate rate is the annual average over annual average percentage change
foreach v of varlist v*{
	gen `v'_gr=100*((`v'/l.`v')-1)
	drop `v'
}

* count number of variables (subtract 5 to get number of releases) and loop through rows  
qui des 
local max=r(k)-5
levelsof i, local(ilist)
foreach i of local ilist{
	* save final entry (first release)
	forvalues j=`max'(-1)1{
		replace fr=v`j'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}
	* save second-to-last final entry (second release)
	forvalues j=`max'(-1)1{
		local k=`j'+1
		cap noisily: replace sr=v`k'_mean_gr in `i' if v`j'_mean_gr[`i']!=.
	}	
}

* current release
rename v`max' cr

* save data
gen variable="growth"
keep variable target_year cr sr fr
order variable target_year cr sr fr
saveold "fed_rtd_growth.dta", replace

* append data sets
append using "fed_rtd_inflation.dta"
append using "fed_rtd_unemployment.dta"
encode variable, gen(v)
xtset v target_year
tsfill, full
replace variable="growth" if v==1
replace variable="inflation" if v==2
replace variable="unemployment" if v==3
drop v
keep if target_year>=1992

* save data
gen type="fe"
saveold "../Processed\usa_actual.dta", replace
cap noisily: erase "fed_rtd_growth.dta"
cap noisily: erase "fed_rtd_inflation.dta"
cap noisily: erase "fed_rtd_unemployment.dta"

********************************************************
******** FED Survey of Professional Forecasters ********
********************************************************
* INDUSTRY note: 1=financial service provider, 2=nonfinancial service provider, 3=no info

* download .xls files from FED website and unzip
* Real GDP growth
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/survey-of-professional-forecasters/data-files/files/individual_prgdp.xlsx fed_spf_growth.xlsx, replace

* GDP price inflation
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/survey-of-professional-forecasters/data-files/files/individual_prpgdp.xlsx fed_spf_inflation.xlsx, replace

* Unemployment rate
*copy https://www.philadelphiafed.org/-/media/research-and-data/real-time-center/survey-of-professional-forecasters/data-files/files/individual_prunemp.xlsx fed_spf_unemployment.xlsx, replace

* import data from .xls files
/*
foreach v in growth inflation unemployment{
	import excel using "fed_spf_`v'.xlsx", clear first
	rename ID fct_source
	rename INDUSTRY industry
	gen variable="`v'"

	* time variables
	rename YEAR fct_year
	rename QUARTER fct_quarter
	drop if fct_year==.
	tostring fct_year fct_quarter, replace force
	gen q="q"
	egen fct_period=concat(fct_year q fct_quarter)
	drop q
	egen t=group(fct_year fct_quarter)
	gen target_year=.
	gen type="fe"
	gen h=.
	order variable t fct_p fct_y fct_q target_y type h fct_s industry P*

	* replace missing values 
	foreach x of varlist _all{
		cap noisily: replace `x'="." if `x'=="#N/A"
	}
	destring _all, replace
	sort fct_year fct_quarter fct_source
	saveold "fed_spf_`v'.dta", replace
}

******** Growth samples with different bin definitions ********
use "fed_spf_growth.dta", clear

* drop "year 3" and "year 4" forecasts
drop PRGDP23-PRGDP44

* 1992Q1-2009Q1
preserve
gen dummy=1 if fct_year==1999&fct_quarter==1
replace dummy=2 if fct_year==2009&fct_quarter==2
carryforward dummy, replace
keep if dummy==1
drop dummy
* drop bins that are not available
drop PRGDP21-PRGDP22
* distinguish this year and next year forecasts
forvalues i=1(1)10{
	rename PRGDP`i' bin`i'_1
}
forvalues i=11(1)20{
	local j=`i'-10
	rename PRGDP`i' bin`j'_2
}
* reshape into long format for each id, so that same bins for different horizons are in one column
egen id=group(t fct_source)
reshape long bin1_ bin2_ bin3_ bin4_ bin5_ bin6_ bin7_ bin8_ bin9_ bin10_, i(id) j(target)
rename bin1_ F6_0T6_9
rename bin2_ F5_0T5_9
rename bin3_ F4_0T4_9
rename bin4_ F3_0T3_9
rename bin5_ F2_0T2_9
rename bin6_ F1_0T1_9
rename bin7_ F0_0T0_9
rename bin8_ FN1_0TN0_1
rename bin9_ FN2_0TN1_1
rename bin10_ FN3_0TN2_1
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=1
saveold "fed_spf_growth_1.dta", replace
restore

* 2009Q2-present
preserve
gen dummy=1 if fct_year==1999&fct_quarter==1
replace dummy=2 if fct_year==2009&fct_quarter==2
carryforward dummy, replace
keep if dummy==2
drop dummy
* distinguish this year and next year forecasts
forvalues i=1(1)11{
	rename PRGDP`i' bin`i'_1
}
forvalues i=12(1)22{
	local j=`i'-11
	rename PRGDP`i' bin`j'_2
}
* reshape into long format for each id, so that same bins for different horizons are in one column
egen id=group(t fct_source)
reshape long bin1_ bin2_ bin3_ bin4_ bin5_ bin6_ bin7_ bin8_ bin9_ bin10_ bin11_, i(id) j(target)
rename bin1_ F6_0T6_9
rename bin2_ F5_0T5_9
rename bin3_ F4_0T4_9
rename bin4_ F3_0T3_9
rename bin5_ F2_0T2_9
rename bin6_ F1_0T1_9
rename bin7_ F0_0T0_9
rename bin8_ FN1_0TN0_1
rename bin9_ FN2_0TN1_1
rename bin10_ FN3_0TN2_1
rename bin11_ FN4_0TN3_1
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=2
saveold "fed_spf_growth_2.dta", replace
restore

******** Inflation samples with different bin definitions ********
use "fed_spf_inflation.dta", clear

* distinguish this year and next year forecasts
forvalues i=1(1)10{
	rename PRPGDP`i' bin`i'_1
}
forvalues i=11(1)20{
	local j=`i'-10
	rename PRPGDP`i' bin`j'_2
}
* reshape into long format for each id, so that same bins for different horizons are in one column
egen id=group(t fct_source)
reshape long bin1_ bin2_ bin3_ bin4_ bin5_ bin6_ bin7_ bin8_ bin9_ bin10_, i(id) j(target)

* identify periods of bin changes and drop observations before 1999Q1
gen dummy=1 if fct_year==1999&fct_quarter==1
replace dummy=2 if fct_year==2014&fct_quarter==1
carryforward dummy, replace
drop if dummy==.

* 1992Q1-2013Q4
preserve
keep if dummy==1
drop dummy
rename bin1_ F8_0T8_9
rename bin2_ F7_0T7_9
rename bin3_ F6_0T6_9
rename bin4_ F5_0T5_9
rename bin5_ F4_0T4_9
rename bin6_ F3_0T3_9
rename bin7_ F2_0T2_9
rename bin8_ F1_0T1_9
rename bin9_ F0_0T0_9
rename bin10_ FN1_0TN0_1
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=3
saveold "fed_spf_inflation_1.dta", replace
restore

* 2014Q1-present
preserve
keep if dummy==2
drop dummy
rename bin1_ F4_0T4_4
rename bin2_ F3_5T3_9
rename bin3_ F3_0T3_4
rename bin4_ F2_5T2_9
rename bin5_ F2_0T2_4
rename bin6_ F1_5T1_9
rename bin7_ F1_0T1_4
rename bin8_ F0_5T0_9
rename bin9_ F0_0T0_4
rename bin10_ FN0_5TN0_1
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=4
saveold "fed_spf_inflation_2.dta", replace
restore

******** Unemployment samples with different bin definitions ********
use "fed_spf_unemployment.dta", clear

* drop "year 3" and "year 4" forecasts
drop PRUNEMP21-PRUNEMP40

* distinguish this year and next year forecasts
forvalues i=1(1)10{
	rename PRUNEMP`i' bin`i'_1
}
forvalues i=11(1)20{
	local j=`i'-10
	rename PRUNEMP`i' bin`j'_2
}

* reshape into long format for each id, so that same bins for different horizons are in one column
egen id=group(t fct_source)
reshape long bin1_ bin2_ bin3_ bin4_ bin5_ bin6_ bin7_ bin8_ bin9_ bin10_, i(id) j(target)

* identify periods of bin changes and drop observations before 1999Q1
gen dummy=1 if fct_year==2009&fct_quarter==2
replace dummy=2 if fct_year==2014&fct_quarter==1
carryforward dummy, replace
drop if dummy==.

* 2009Q2-2013Q4
preserve
keep if dummy==1
drop dummy
rename bin1_ F11_0T11_9
rename bin2_ F10_0T10_9
rename bin3_ F9_5T9_9
rename bin4_ F9_0T9_4
rename bin5_ F8_5T8_9
rename bin6_ F8_0T8_4
rename bin7_ F7_5T7_9
rename bin8_ F7_0T7_4
rename bin9_ F6_0T6_9
rename bin10_ F5_0T5_9
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=5
saveold "fed_spf_unemployment_1.dta", replace
restore

* 2014Q1-present
preserve
keep if dummy==2
drop dummy
rename bin1_ F9_0T9_9
rename bin2_ F8_0T8_9
rename bin3_ F7_5T7_9
rename bin4_ F7_0T7_4
rename bin5_ F6_5T6_9
rename bin6_ F6_0T6_4
rename bin7_ F5_5T5_9
rename bin8_ F5_0T5_4
rename bin9_ F4_0T4_9
rename bin10_ F3_0T3_9
* reshape into long format for each id, so that all probabilities are in one column
drop id
egen id=group(t target fct_source)
reshape long F, i(id) j(binn) string
rename F p
gen part=6
saveold "fed_spf_unemployment_2.dta", replace
restore

******** merge all data sets ********
use "fed_spf_growth_1.dta", clear
append using "fed_spf_growth_2.dta"
append using "fed_spf_inflation_1.dta"
append using "fed_spf_inflation_2.dta"
append using "fed_spf_unemployment_1.dta"
append using "fed_spf_unemployment_2.dta"

* target years and forecast horizon
drop t
egen t=group(fct_year fct_quarter)
replace target_year=fct_year if target==1
replace target_year=fct_year+1 if target==2
replace h=4*(target_y-fct_y)+(4-fct_q)+1

* save data
saveold "../Processed\usa_spf.dta", replace
cap noisily: erase "fed_spf_inflation.dta"
cap noisily: erase "fed_spf_inflation_1.dta"
cap noisily: erase "fed_spf_inflation_2.dta"
cap noisily: erase "fed_spf_cpi.dta"
cap noisily: erase "fed_spf_cpi_1.dta"
cap noisily: erase "fed_spf_growth.dta"
cap noisily: erase "fed_spf_growth_1.dta"
cap noisily: erase "fed_spf_growth_2.dta"
cap noisily: erase "fed_spf_unemployment.dta"
cap noisily: erase "fed_spf_unemployment_1.dta"
cap noisily: erase "fed_spf_unemployment_2.dta"
*/

******************************
******** process data ********
******************************
cd "../"
use "Processed\usa_spf.dta", clear

* split bin names and generate lower and upper bound of bin 
split binn, p("T")
gen miss=.
split binn1, p("_")
gen minus="-" if substr(binn11,1,1)=="N"
replace binn11=substr(binn11,2,2) if substr(binn11,1,1)=="N"
egen double lower=concat(minus binn11 miss binn12)
drop binn11 binn12 minus 

split binn2, p("_")
gen minus="-" if substr(binn21,1,1)=="N"
replace binn21=substr(binn21,2,2) if substr(binn21,1,1)=="N"
egen double upper=concat(minus binn21 miss binn22)
drop binn* minus miss
destring lower upper, replace

* extend lower- and upper end of interior bins by 0.05 percentage points
replace lower=lower-0.05
replace upper=upper+0.05

* group variable for bins
egen binn=group(part lower)
drop id
egen id=group(variable t target fct_source)
sort id binn
egen double lower_min=min(lower), by(id)
egen double upper_max=max(upper), by(id)

* calculate number of bins used 
bys id: egen nbins=count(p) if p!=0&p!=.

* calculate total probability mass and drop if forecasters do not report a density forecast or reported probabilities do not sum to one as in Abel et al. (2016)
bys id: egen pmasstotal=sum(p), missing
drop if pmasstotal==.|pmasstotal<=99.1|pmasstotal>=100.9

* replace unused bins of forecasters that report density forecasts with zeroes
replace p=0 if p==.

* merge realizations
merge m:m variable target_year type using "Processed\usa_actual.dta"
drop if _merge==2
drop _merge
sort id binn

******** density forecast performance ********

* indicator for realization (be careful if realization outside available bins)
gen ind=0 if fr!=.
replace ind=1 if fr>=lower&fr<=upper
replace ind=1 if fr!=.&fr<lower_min&lower==lower_min
replace ind=1 if fr!=.&fr>upper_max&upper==upper_max

* qps score
bys id: egen qps=total((p/100-ind)^2) if fr!=.

* rps score 
bys id: gen cdf=sum(p)/100
bys id: gen cdf_ind=sum(ind) if ind!=.
bys id: egen rps=total((cdf-cdf_ind)^2) if fr!=.
drop cdf* ind cdf_ind

******** rounding schemes ********

* fix bounds of individual densities at left-most/right-most bin with non-zero probability
drop if p==0

* if left-most (right-most) bin is exterior, set bound one (or two) percentage point(s) below (above) the right (left) endpoint of the lowest (highest) bin during the survey history 
* in other words, assume open intervals have twice the length of the other intervals
gen double diff=upper-lower
replace lower=lower-diff if lower==lower_min
replace upper=upper+diff if upper==upper_max

* integer-based: probabilities multiple of tau (note that float has higher precision but trims extreme decimal places)
gen float p2=p
forvalues tau=1(1)10{
	gen mult`tau'=(int(p2/`tau')*`tau')==p2 if p2!=0
	replace mult`tau'=0 if mult`tau'==.
	bys id: egen bin_m`tau'=mode(mult`tau'), min
	replace bin_m`tau'=1-bin_m`tau'
}
drop p2

* count number of decimals of each probability number
tostring p, replace force
split p, p(.)
gen d=0
replace d=strlen(p2)
bys id: egen d_avg=mean(d)

**** Figure 2: Relative frequencies of the number of decimals reported in the SPF
preserve
keep if target_year>=2000&target_year<=2017
gen v=1 if variable=="inflation"
replace v=2 if variable=="growth"
replace v=3 if variable=="unemployment"
* number of probabilities per variable
gen prob=1
egen count_all=total(prob), by(v)
* number of probabilities per variable and digit
gen prob_dec=1 if d>0
egen count_d_each=total(prob_dec) if d>0, by(v d)
* share
gen share_all=100*(count_d_each/count_all)
graph bar (mean) share_all if d>0, over(v, gap(5)) asyvar bar(1, color(red)) bar(2, color(dkgreen)) bar(3, color(dknavy)) over(d, label(labsize(small))) title("") ytitle("%", orientation(horizontal) size(small)) ytick(0(1)7) ylabel(0(1)7, angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) plotr(m(zero)) legend(off)
graph export "Figures\usa_decimals_share.pdf", replace
restore

* decimal-based: any, most or all probabilities contain decimals
gen bin_dec=d>0 
bys id: egen nbins_dec=total(bin_dec) 
gen rho=nbins_dec/nbins
gen bin_any=rho>0
gen bin_most=rho>0.5
gen bin_all=rho==1
destring p, replace
drop mult* p1 p2 d bin_dec nbins_dec rho

******** histogram moments ********

* bin midpoint 
gen double midpoint=lower+(upper-lower)/2

* histogram mean
replace p=p/100
bys id: egen point_imp=total(midpoint*p) 

* forecast errors	
gen err=fr-point_imp 
gen sqerr=(fr-point_imp)^2 
gen abserr=abs(fr-point_imp) 

* histogram variance
bys id: egen variance=total((midpoint-point_imp)^2*p) 

* skewness 
bys id: egen skew=total((midpoint-point_imp)^3*p) if nbins>1
replace skew=skew/variance^(3/2)

* kurtosis
bys id: egen kurt=total((midpoint-point_imp)^4*p) if nbins>1
replace kurt=kurt/variance^(4/2)

******** beta distributions ********
sort id binn
bys id: gen F=100*sum(p)
foreach x in a b l r c point_beta variance_beta{
	qui gen `x'=.
}

levelsof variable, clean local(vlist)
foreach v of local vlist{
	levelsof id if variable=="`v'", clean local(idlist)
	foreach id of local idlist{
	
		**** support of Beta distribution
		dis "id = "`id'
		qui sum lower if id==`id'
		local l=`r(min)'
		qui sum upper if id==`id'
		local r=`r(max)'
		qui sum nbins if id==`id'
		
		**** No bins used (redundant)
		if r(N)==0{
			dis "No observations"
		}
		
		**** all other cases (triangle over one or two bins, beta distribution over more than two)
		else{
		
			**** Case 1: triangle distribution over one bin
			if r(mean)==1{
				local c		         		= (`l'+`r')/2
				replace l  	         		= `l' if id==`id'
				replace r            		= `r' if id==`id'
				replace c	         		= `c' if id==`id'
				replace point_beta   		= `c' if id==`id'
				replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
			}	
			
			**** Case 2: triangle distribution over two bins
			else if r(mean)==2{
			
				* determine boundary between both bins
				qui sum upper if id==`id'
				local m=r(min)
				
				* determine probability mass in both bins
				qui sum F if id==`id'
				local p_l=r(min)/100
				local p_r=1-`p_l'
				
				**** Case 2a: lower bin contains more probability mass
				if `p_l'>=.5{
					local r 	         		= `m'+((`m'-`l')*sqrt(.5*`p_r'))/(1-sqrt(.5*`p_r'))
					local c		         		= (`l'+`r')/2
					replace l            		= `l' if id==`id'
					replace r           		= `r' if id==`id'
					replace point_beta   		= (`l'+`c'+`r')/3 if id==`id'
					replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
				}
				
				**** Case 2b: upper bin contains more probability mass
				else{
					local l 	         		= `m'-((`r'-`m')*sqrt(.5*`p_l'))/(1-sqrt(.5*`p_l'))
					local c		         		= (`l'+`r')/2
					replace l            		= `l' if id==`id'
					replace r            		= `r' if id==`id'	
					replace point_beta   		= (`l'+`c'+`r')/3 if id==`id'
					replace variance_beta       = ((`l')^2+(`r')^2+(`c')^2-(`l')*(`r')-(`l')*(`c')-(`c')*(`r'))/18 if id==`id'
				}
			}
			
			**** Case 3: generalized beta distribution over more than two bins
			else{
				qui nl (F=100*ibeta({a},{b},(upper-`l')/(`r'-`l'))) if id==`id', initial(a 2 b 2) nolog 
				mat tempb = e(b)
				svmat double tempb
				replace a          		  = tempb1[1] if id==`id'
				replace b          		  = tempb2[1] if id==`id'
				drop temp*
				replace l          		  = `l' if id==`id'
				replace r          		  = `r' if id==`id'	
				replace point_beta 		  = a/(a+b)*(`r'-`l')+`l' if id==`id'
				replace variance_beta     = a*b/((a+b+1)*(a+b)^2)*(`r'-`l')^2 if id==`id'
			}
		}
	}
}
saveold "Processed\usa_spf_processed.dta", replace

******** prepare to reshape and rearrange data ********
use "Processed\usa_spf_processed.dta", clear

* suffix to be added to variables in wide format
gen suffix="_g"
replace suffix="_i" if variable=="inflation"
replace suffix="_u" if variable=="unemployment"

* drop duplicates of each id
duplicates drop id, force
drop variable part* p lower* upper* diff midpoint binn pmasstotal id F a b l r c

* share of predictions with one bin (FN 11)
preserve
keep if target_year>=2000&target_year<=2017
count if nbins==1
local onebin=r(N)
count  
local all=r(N)
dis "Share of histograms with one bin = "100*(`onebin'/`all')
restore

******** reshape and rearrange data ********
egen id=group(fct_p target fct_source)
drop target
sort id suffix 
reshape wide target* point* cr sr fr qps rps nbins d_avg bin_* *err variance* skew kurt, i(id) j(suffix) string
drop id

* new target variable
gen target=1
replace target=2 if h>=5

* check for which target years realizations are available
keep if fct_year>=1999
keep if target_year_g>=2000&target_year_g<=2017
drop t
egen t=group(fct_year fct_quarter)

* drop unemployment rate forecasts from 2009 and 2010 (forecast horizons partially missing)
rename target_year_u target_year
foreach v of varlist *_u{
	replace `v'=. if target_year==2009|target_year==2010
}
rename target_year target_year_u

* additional variables
foreach x in g i u{

	* average point forecast 
	bys t target: egen point_avg_`x'=mean(point_imp_`x')
	
	* disagreement (variance)
	gen dev_`x'=(point_imp_`x'-point_avg_`x')^2
	bys t target: egen participants_`x'=count(point_imp_`x')
	bys t target: egen sum_`x'=total(dev_`x') if participants_`x'>0
	gen disagreement_`x'=(1/(participants_`x'-1))*sum_`x'
	drop dev_`x' participants_`x' sum_`x'	

	* average uncertainty
	bys t target: egen ubar_`x'=mean(variance_`x')
	bys t target: egen ubar_`x'_rou=mean(variance_`x') if bin_m5_`x'==0
	bys t target: egen ubar_`x'_non=mean(variance_`x') if bin_m5_`x'==1
	
}

* order and save data
order t fct_period fct_year fct_quarter type h target fct_source industry target_year_g fr_g sr_g cr_g nbins_g d_avg_g bin_m1_g-bin_m10_g bin_any_g bin_most_g bin_all_g point_imp_g err_g abserr_g sqerr_g variance_g skew_g kurt_g qps_g rps_g point_beta_g variance_beta_g point_avg_g disagreement_g ubar_g* target_year_i fr_i sr_i cr_i nbins_i d_avg_i bin_m1_i-bin_m10_i bin_any_i bin_most_i bin_all_i point_imp_i err_i abserr_i sqerr_i variance_i skew_i kurt_i qps_i rps_i point_beta_i variance_beta_i point_avg_i disagreement_i ubar_i* target_year_u fr_u sr_u cr_u nbins_u d_avg_u bin_m1_u-bin_m10_u bin_any_u bin_most_u bin_all_u point_imp_u err_u abserr_u sqerr_u variance_u skew_u kurt_u qps_u rps_u point_beta_u variance_beta_u point_avg_u disagreement_u ubar_u*
sort t target fct_source
saveold "Processed\usa_spf_processed.dta", replace

window manage close graph
