********************************************************************************************
******** Uncertainty measures from partially rounded probabilistic forecast surveys ********
********************************************************************************************
cd "SET WORKING DIRECTLY TO MAIN-FOLDER"

********************************************************
******** ECB Survey of Professional Forecasters ********
********************************************************
use "Processed\euro_spf_processed.dta", clear	

******** Section 3: Data ********

**** Table II: Number of density forecasts provided by SPF participants
foreach x in i g u{
	count if variance_`x'!=.
	local sum=r(N)
	cap noisily: logout, save("Tables\Table_size") excel replace auto(2) dec(2): bys h: count if variance_`x'!=.
	preserve
	xmluse "Tables\Table_size.xml", clear cells(A3:A17)
	drop if var1=="->"
	destring var1, replace
	gen i=1
	gen h=_n
	reshape wide var1, i(i) j(h)
	drop i
	order *8 *7 *6 *5 *4 *3 *2 *1
	gen sum=`sum'
	listtex _all using "Tables\Table_size_ecb_`x'.tex", replace rstyle(tabular)
	cap noisily: erase "Tables\Table_size.xml"
	cap noisily: erase "Tables\Table_size.txt"
	restore
}

**** total number of forecasters in common sample
preserve
duplicates drop fct_s, force
count
restore

**** number of forecasters in first and last survey round
inspect fct_s if t==1
inspect fct_s if t==76

**** number of forecasters per survey round
levelsof t, local(tlist)
foreach t of local tlist{
	preserve
	qui keep if t==`t'
	qui duplicates drop fct_s, force
	count if t==`t'
	restore
}

**** share of histograms that assign 100% probability to a single bin
tab nbins_i
tab nbins_g
tab nbins_u

**** Figures with actuals, consensus forecasts and average uncertainties for each forecast horizon
preserve
foreach x in i g u{

	**** Figure 3: Realizations and consensus forecasts from the SPF
	if "`x'"=="i"{
		local f 0
		local t 4
		local b 1
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f -5
		local t 6
		local b 1
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 4
		local t 13
		local b 1
		local color "dknavy"
		local description "Unemployment"
	}
	sort target_year_`x'
	twoway (line fr_`x' cr_`x' target_year_`x', title("") ytitle("Percentage points", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(7) ring(0)) plotr(m(zero)) lwidth(medthick medthick) lcolor(black black) lpattern(solid shortdash)) (scatter point_avg_`x' target_year_`x' if h>1&h<8, msymbol(smx) mcolor(/*`color'*/gs10)) (scatter point_avg_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter point_avg_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\euro_actuals_`x'.pdf", replace	
	
	**** Figure 4: Average ex-ante uncertainty
	if "`x'"=="i"{
		local f 0
		local t 0.5
		local b 0.1
	}
	if "`x'"=="g"{
		local f 0
		local t 0.7
		local b 0.1
	}
	if "`x'"=="u"{
		local f 0
		local t 0.6
		local b 0.1
	}
	twoway (scatter ubar_`x' target_year_`x' if h>1&h<8, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) msymbol(smx) mcolor(/*`color'*/gs10)) (scatter ubar_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter ubar_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\euro_ubar_`x'.pdf", replace	
	
}
restore

******** Section 5.1: Rounders and non-rounders in the SPF data ********

**** Figure 5: Share of rounded histograms (integer-based categorization)
foreach x in i g u{
	if "`x'"=="i"{
		local color red
		local description "Inflation"
	}
	if "`x'"=="g"{
		local color dkgreen
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local color dknavy
		local description "Unemployment"
	}
	preserve
	forvalues tau=1(1)10{
		replace bin_m`tau'_`x'=100*(1-bin_m`tau'_`x')
	}
	graph bar (mean) bin_m1_`x' bin_m2_`x' bin_m3_`x' bin_m4_`x' bin_m5_`x' bin_m6_`x' bin_m7_`x' bin_m8_`x' bin_m9_`x' bin_m10_`x', b1title(" ") text(-12 50 "{&tau}") showyvars yvaroptions(relabel(1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6" 7 "7" 8 "8" 9 "9" 10 "10") label(labsize(vsmall))) bargap(10) title("") ytitle("%", orientation(horizontal) size(small)) ytick(105, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(1) ring(0)) plotr(m(zero)) bar(1, color(`color')) bar(2, color(`color')) bar(3, color(`color')) bar(4, color(`color')) bar(5, color(`color')) bar(6, color(`color')) bar(7, color(`color')) bar(8, color(`color')) bar(9, color(`color')) bar(10, color(`color')) blabel(bar, format(%9.2f) size(vsmall))
	graph export "Figures\euro_tau_`x'.pdf", replace
	restore
}	

**** correlations across categorizations and variables
pwcorr bin_any_* bin_m5_*, sig star(0.05)

**** for each variable, calculate the share of observations unanimously classified by both categorizations
foreach x in i g u{
	dis "Variable = `x' "
	
	* count the total number of classified histograms
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.
	local total=r(N)
	
	* number and share of histograms unanimously classified as non-rounders across categorizations
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==1&bin_m5_`x'==1
	local non_unanimous=r(N)
	dis "Share of histograms unanimously classified as non-rounders across categorizations = "`non_unanimous'/`total'
	
	* number and share histograms unanimously classified as rounders across categorizations
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==0&bin_m5_`x'==0
	local rou_unanimous=r(N)
	dis "Share of histograms unanimously classified as rounders across categorizations = "`rou_unanimous'/`total'
	
	* share of unanimously classified histograms across categorizations
	dis "Share of unanimously classified histograms across categorizations = "(`non_unanimous'+`rou_unanimous')/`total'
	
	* number and share of histograms classified as rounders by any but as non-rounders by m5
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==0&bin_m5_`x'==1
	local not_unanimous_a=r(N)
	dis "Share of histograms classified as rounders by any but as non-rounders by m5 = "`not_unanimous_a'/`total'
	
	* number and share of histograms classified as non-rounders by any but as rounders by m5
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==1&bin_m5_`x'==0
	local not_unanimous_b=r(N)
	dis "Share of histograms classified as non-rounders by any but as rounders by m5 = "`not_unanimous_b'/`total'
	
	* share of differently classified histograms across categorizations
	dis "Share of differently classified histograms across categorizations = "(`not_unanimous_a'+`not_unanimous_b')/`total'
	
	dis ""
}

**** for each categorization, calculate the share of observations unanimously classified across all three variables
foreach v in any m5{
	dis "Categorization = `v' "

	* count the total number of classified histograms
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.
	local total=r(N)
	
	* number and share of histograms unanimously classified as non-rounders across variables
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.&bin_`v'_i==1&bin_`v'_g==1&bin_`v'_u==1
	local non_unanimous=r(N)
	dis "Share of histograms unanimously classified as non-rounders across variables = "`non_unanimous'/`total'
	
	* number and share of histograms unanimously classified as rounders across variables
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.&bin_`v'_i==0&bin_`v'_g==0&bin_`v'_u==0
	local rou_unanimous=r(N)
	dis "Share of histograms unanimously classified as rounders across variables = "`rou_unanimous'/`total'
	
	* share of unanimously classified histograms across variables
	dis "Share of unanimously classified histograms across variables for `v' = "(`non_unanimous'+`rou_unanimous')/`total'
	
	dis ""
}

**** Table III: Share of non-rounded observations across horizons
foreach x in i g u{
	bys h: sum bin_any_`x' bin_most_`x' bin_all_`x' bin_m5_`x' bin_m10_`x'
	foreach v in any most all m5 m10{
		cap noisily: logout, save("Tables\Table_share") excel replace auto(4) dec(4): bys h: tabstat bin_`v'_`x'
		preserve
		xmluse "Tables\Table_share.xml", clear cells(B5:B40)
		drop if var2==""|var2=="h"|var2=="mean"
		gen i=1
		gen h=_n
		destring var2, replace
		replace var2=100*var2
		format var2 %5.2f
		reshape wide var2, i(i) j(h)
		drop i
		order *8 *7 *6 *5 *4 *3 *2 *1
		listtex _all using "Tables\Table_share_ecb_`x'_`v'.tex", replace rstyle(tabular)
		cap noisily: erase "Tables\Table_share.xml"
		cap noisily: erase "Tables\Table_share.txt"
		restore
	}
}	

**** Figure 6: Time-variation in the share of non-rounders
foreach x in i g u{
	bys t: egen share_any_`x'=mean(bin_any_`x')
	replace share_any_`x'=100*share_any_`x'
	bys t: egen share_m5_`x'=mean(bin_m5_`x')
	replace share_m5_`x'=100*share_m5_`x'
}
qui sum t
local max=r(max)
line share_any_i share_any_g share_any_u t, title("") ytitle("%", orientation(horizontal) size(small)) xtitle("") xtick(1(1)`max') xlabel(5 "2000" 21 "2004" 37 "2008" 53 "2012" 69 "2016", labsize(small)) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) lcolor(red dkgreen dknavy) lwidth(medthick medthick medthick) lpattern(solid longdash shortdash) plotr(m(zero)) ytick(0(10)50) ylabel(0(10)50, angle(horizontal) labsize(small)) 
graph export "Figures\euro_shares_any.pdf", replace
line share_m5_i share_m5_g share_m5_u t, title("") ytitle("%", orientation(horizontal) size(small)) xtitle("") xtick(1(1)`max') xlabel(5 "2000" 21 "2004" 37 "2008" 53 "2012" 69 "2016", labsize(small)) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) lcolor(red dkgreen dknavy) lwidth(medthick medthick medthick) lpattern(solid longdash shortdash) plotr(m(zero)) ytick(0(10)50) ylabel(0(10)50, angle(horizontal) labsize(small)) 
graph export "Figures\euro_shares_m5.pdf", replace
**** comparison to Table III:
bys h: sum share*

**** Share of non-rounders in 2009Q4 and 2013Q3 mentioned in discussion
sum bin_m5* if t==44
sum bin_m5* if t==59

******** Section 5.2: Analysis of variance misalignment ********
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is zero)
	drop if nbins_`x'==1
	
	**** Variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/var_mean_`x'	
	
	**** Figures 7 and 8: Variance misalignment in the SPF data (decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 7
		local b 1
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 20
		local b 5
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 8
		local b 2
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_m5.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_any.pdf", replace
	
	restore
}

**** Figures 9 and 10: Average number of bins used / average ex-ante variances reported by rounders and non-rounders
preserve
keep nbins* variance* bin_any* bin_m5*
drop *beta*
gen i=_n
reshape long nbins_ variance_ bin_any_ bin_m5_, i(i) j(var) string
encode var, gen(v)
replace v=0 if v==2
graph bar (mean) nbins_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_any_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(11, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\euro_avg_nbins_any.pdf", replace
graph bar (mean) nbins_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_m5_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(11, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\euro_avg_nbins_m5.pdf", replace
graph bar (mean) variance_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_any_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(2.2, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\euro_avg_variance_any.pdf", replace
graph bar (mean) variance_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_m5_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(2.2, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\euro_avg_variance_m5.pdf", replace
restore

**** Figure 11: Average uncertainty of rounders and non-rounders for one-year-ahead predictions 
preserve
keep if fct_quarter==1&h==4
sort t
foreach x in i g u{
	if "`x'"=="i"{
		local f 0
		local t 0.5
		local b 0.1
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f 0
		local t 0.8
		local b 0.2
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 0
		local t 0.9
		local b 0.1
		local color "dknavy"
		local description "Unemployment"
	}
	line ubar_`x'_rou ubar_`x'_non fct_year, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(5) ring(0)) plotr(m(zero)) lcolor(`color' `color') lpattern(solid longdash_dot) lwidth(medthick medthick)
	graph export "Figures\euro_ubar_`x'_m5_both.pdf", replace	
}
restore

******** Section 5.3: Differences in histogram characteristics ********
foreach x in nbins variance abserr sqerr qps rps skew kurt{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_`x'\Table_euro_`x'_`v'.xml"
		cap noisily: erase "Tables\Tables_`x'\Table_euro_`x'_wide_`v'.xml"
	}
}
foreach x in i g u{
	foreach h in 8 7 6 5 4 3 2 1{
	
		preserve
		keep if h==`h'
		drop t
		egen t=group(fct_year fct_quarter)
		xtset fct_s t
		qui sum h
		local h=r(mean)
		
		**** rule of thumb for bandwidth selection
		qui sum t 
		local bw=round(4*(r(max)/100)^(2/9))
		
		**** time-fixed effects  
		qui tab t, gen(t_)
		
		foreach v in m5 m10 any most all{
		
			**** Fraction of model-based forecasters
			qui sum bin_`v'_`x'
			local bfrac=100*r(mean)
		
			**** number of bins 
			cap noisily: qui reg nbins_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 nbins_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_nbins\Table_euro_nbins_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** variances
			cap noisily: qui reg variance_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_euro_variance_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

			**** absolute forecast errors
			cap noisily: qui reg abserr_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 abserr_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_abserr\Table_euro_abserr_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
				
			**** squared forecast errors
			cap noisily: qui reg sqerr_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 sqerr_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_sqerr\Table_euro_sqerr_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
					
			******** additional histogram characteristics (not included in the main article) ********
					
			**** quadratic probability score
			cap noisily: qui reg qps_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 qps_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_qps\Table_euro_qps_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** ranked probability score
			cap noisily: qui reg rps_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 rps_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_rps\Table_euro_rps_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
		
			**** skewness
			cap noisily: qui reg skew_`x' bin_`v'_`x' t_* if skew_`x'>-50
			local r2=e(r2_a)
			cap noisily: qui newey2 skew_`x' bin_`v'_`x'  t_* if skew_`x'>-50, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_skew\Table_euro_skew_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** kurtosis
			cap noisily: qui reg kurt_`x' bin_`v'_`x' t_* if kurt_`x'<50
			local r2=e(r2_a)
			cap noisily: qui newey2 kurt_`x' bin_`v'_`x' t_* if kurt_`x'<50, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_kurt\Table_euro_kurt_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
						
			******** consider forecasters who use at least 4 bins (not included in the main article) ********
		
			**** number of bins
			cap noisily: qui reg nbins_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 nbins_`x' bin_`v'_`x' t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_nbins\Table_euro_nbins_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** variances
			cap noisily: qui reg variance_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_`x' bin_`v'_`x' t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_euro_variance_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

			**** absolute forecast errors
			cap noisily: qui reg abserr_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 abserr_`x' bin_`v'_`x'  t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_abserr\Table_euro_abserr_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
						
			**** squared forecast errors
			cap noisily: qui reg sqerr_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 sqerr_`x' bin_`v'_`x'  t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_sqerr\Table_euro_sqerr_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
				
		}
		restore
	}
}
foreach x in nbins variance abserr sqerr qps rps skew kurt{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_`x'\Table_euro_`x'_`v'.txt"
		cap noisily: erase "Tables\Tables_`x'\Table_euro_`x'_wide_`v'.txt"
	}
}

**** Figures 12-13: Average deviations in histogram characteristics of rounders and non-rounders (plus Figures A.4-A.5 and A.7-A.8 from Appendix and Figures 7-12 from Supplement)
preserve
foreach x in nbins variance abserr sqerr qps rps skew kurt nbins_wide variance_wide abserr_wide sqerr_wide{

	if "`x'"=="nbins_wide"{
		local y "nbins"
		local p 1
		local f 0
		local b 1
		local t 7
	}
	if "`x'"=="variance_wide"{
		local y "variance"
		local p 1
		local f -1
		local b 1
		local t 2
	}
	if "`x'"=="abserr_wide"{
		local y "abserr"
		local p 1
		local f -0.2
		local b 0.2
		local t 0.6
	}
	if "`x'"=="sqerr_wide"{
		local y "sqerr"
		local p 1
		local f -1
		local b 1
		local t 2
	}
	if "`x'"=="qps"{
		local y "qps"
		local p 11
		local f -0.4
		local b 0.2
		local t 0.4
	}
	if "`x'"=="rps"{
		local y "rps"
		local p 1
		local f -0.4
		local b 0.2
		local t 0.8
	}
	if "`x'"=="skew"{
		local y "skew"
		local p 7
		local f -5
		local b 1
		local t 5
	}
	if "`x'"=="kurt"{
		local y "kurt"
		local p 11
		local f -2
		local b 2
		local t 8
	}
	foreach m in any most all m5 m10{

		if "`x'"=="nbins"&"`m'"=="any"|"`x'"=="nbins"&"`m'"=="m5"{
			local y "nbins"
			local p 7
			local f 0
			local b 2
			local t 6
		}
		if "`x'"=="nbins"&"`m'"=="most"|"`x'"=="nbins"&"`m'"=="all"|"`x'"=="nbins"&"`m'"=="m10"{
			local y "nbins"
			local p 7
			local f 0
			local b 2
			local t 8
		}
		if "`x'"=="variance"&"`m'"=="any"|"`x'"=="variance"&"`m'"=="m5"{
			local y "variance"
			local p 1
			local f 0
			local b 1
			local t 2
		}
		if "`x'"=="variance"&"`m'"=="most"|"`x'"=="variance"&"`m'"=="all"|"`x'"=="variance"&"`m'"=="m10"{
			local y "variance"
			local p 1
			local f -1
			local b 1
			local t 2
		}
		if "`x'"=="abserr"&"`m'"=="any"|"`x'"=="abserr"&"`m'"=="m5"{
			local y "abserr"
			local p 1
			local f -0.1
			local b 0.1
			local t 0.2			
		}
		if "`x'"=="abserr"&"`m'"=="most"|"`x'"=="abserr"&"`m'"=="all"|"`x'"=="abserr"&"`m'"=="m10"{
			local y "abserr"
			local p 1
			local f -0.1
			local b 0.1
			local t 0.2		
		}
		if "`x'"=="sqerr"&"`m'"=="any"|"`x'"=="sqerr"&"`m'"=="m5"{
			local y "sqerr"
			local p 1
			local f -0.2
			local b 0.1
			local t 0.3
		}
		if "`x'"=="sqerr"&"`m'"=="most"|"`x'"=="sqerr"&"`m'"=="all"|"`x'"=="sqerr"&"`m'"=="m10"{
			local y "sqerr"
			local p 1
			local f -0.2
			local b 0.1
			local t 0.3
		}
		
		xmluse "Tables\Tables_`y'\Table_euro_`x'_`m'", clear cells(B6:Y11)
		drop in 2 
		drop in 3
		drop in 4
		foreach v of varlist var10-var17{
			forvalues i=1(1)1{
				local j=`i'+1
				replace `v'=`v'[`j'] in `i'
			}
		}
		foreach v of varlist var18-var25{
			forvalues i=1(1)1{
				local j=`i'+2
				replace `v'=`v'[`j'] in `i'
			}
		}
		drop in 2/3
		gen i=1
		reshape long var, i(i) j(j)
		gen variable="inflation"
		replace variable="growth" if j>=10&j<=17
		replace variable="unemployment" if j>=18&j<=25
		drop i j
		replace var=subinstr(var, "*", "",.)
		destring var, replace
		seq h, f(8) t(1) b(1)
		twoway (line var h if variable=="inflation", title("") ytitle("{&beta}{subscript:h}", orientation(horizontal)) xtitle("") xscale(reverse) xtick(1(1)8) xlabel(1(1)8, labsize(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) lcolor(red) lwidth(medthick) plotr(m(zero)) legend(title("D{superscript:`m'}", size(medium)) order(0) region(lstyle(none)) position(`p') ring(0))) (scatter var h if variable=="inflation", mcolor(red) msymbol(diamond)) (line var h if variable=="growth", lcolor(dkgreen) lwidth(medthick) lpattern(longdash)) (scatter var h if variable=="growth", mcolor(dkgreen) msymbol(diamond)) (line var h if variable=="unemployment", lcolor(dknavy) lwidth(medthick) lpattern(shortdash)) (scatter var h if variable=="unemployment", mcolor(dknavy) msymbol(diamond))
		graph export "Figures\euro_`x'_`m'.pdf", replace
		
	}
}
restore

******** Section 6.1: Variance misalignment and the width of histogram bins ********
use "Processed\euro_spf_processed.dta", clear
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is zero)
	drop if nbins_`x'==1
	
	**** Adjusted variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/(4*var_mean_`x')	
	
	**** Figures 15 and XX: Adjusted variance misalignment in the SPF data (scenario B, decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 2
		local b 1
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 5
		local b 1
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 3
		local b 1
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_m5_adj.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_any_adj.pdf", replace
	
	restore
}

**************************
******** Appendix ********
**************************

**** Table A.II: Pooled MSE for the ECB-SPF and the FED-SPF
use "Processed\euro_spf_processed.dta", clear	
* Full sample MSE
sum sqerr*
* Excluding 2009
sum sqerr* if target_year_g!=2009

**** Tables IV, A.III and A.IV: Pooled regressions for average deviations of (inflation/real GDP growth/unemployment) histogram characteristics in the ECB-SPF
use "Processed\euro_spf_processed.dta", clear	

* FE dummies
tab h, gen(h_)
tab fct_period, gen(t_)
tab fct_source, gen(i_)

* bandwidth selection
sum t
local bw=round(4*(r(max)/100)^(2/9))
dis `bw'

* panel structure
drop t
egen t=group(fct_year fct_quarter h)
xtset fct_s t

* Pooled regressions
foreach x in i g u{
	cap noisily: erase "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.xml"
	preserve
	
	* interactions of horizon-FE and rounding dummy
	drop h_1
	forvalues h=2(1)8{
		gen ia_`h'=bin_m5_`x'*h_`h'
	}
	
	* loop over histogram characteristics
	foreach y in nbins variance variance_beta abserr sqerr{
	
		* no forecaster-FE
		qui reg `y'_`x' bin_m5_`x' ia_* h_* t_*
		local r2a=e(r2_a)
		qui newey2 `y'_`x' bin_m5_`x' ia_* h_* t_*, lag(`bw') force
		dis "DV: `y'_`x', no forecaster-FE"
		test bin_m5_`x' h_2 h_3 h_4 h_5 h_6 h_7 h_8 ia_2 ia_3 ia_4 ia_5 ia_6 ia_7 ia_8
		test (ia_2=ia_3)
		test (ia_3=ia_4)
		test (ia_4=ia_5)
		test (ia_5=ia_6)
		test (ia_6=ia_7)
		test (ia_7=ia_8)
		cap noisily: outreg2 using "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.xml", excel append auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(Adj. R2, `r2a') addtext(Horizon-FE, Yes, Time-FE, Yes, Forecaster-FE, No) title("Pooled regressions for differences in histogram characteristics") drop(h_* t_* i_* o.t_* o.i_*) noaster
		
		* including forecaster-FE
		qui reg `y'_`x' bin_m5_`x' ia_* h_* t_* i_*
		local r2a=e(r2_a)
		qui newey2 `y'_`x' bin_m5_`x' ia_* h_* t_* i_*, lag(`bw') force
		dis "DV: `y'_`x', forecaster-FE"
		test bin_m5_`x' h_2 h_3 h_4 h_5 h_6 h_7 h_8 ia_2 ia_3 ia_4 ia_5 ia_6 ia_7 ia_8
		test (ia_2=ia_3)
		test (ia_3=ia_4)
		test (ia_4=ia_5)
		test (ia_5=ia_6)
		test (ia_6=ia_7)
		test (ia_7=ia_8)
		cap noisily: outreg2 using "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.xml", excel append auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(Adj. R2, `r2a') addtext(Horizon-FE, Yes, Time-FE, Yes, Forecaster-FE, Yes) title("Pooled regressions for differences in histogram characteristics") drop(h_* t_* i_* o.t_* o.i_*) noaster
	
	}
	restore
	cap noisily: erase "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.txt"
}

**** Latex table
preserve
foreach x in i g u{
	cap noisily: xmluse "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.xml", clear cells(A6:K29)
	replace var1=" $ D_{i,t,h}^{\text{m}5}$" if var1=="bin_m5_`x'"
	forvalues j=2(1)8{
		replace var1=" $ D_{i,t,h}^{\text{m}5} \times D_{i,t,h}^{h=`j'}$" if var1=="ia_`j'"
	}
	replace var1=" $ \bar{R}^2$" if var1=="Adj. R2"
	cap noisily: listtex _all using "Tables/Tables_pooled/Table_euro_panel_regressions_`x'.tex", replace rstyle(tabular)
}	
restore

**** Figures A.1: Average ex-ante uncertainty based on beta distributions
use "Processed\euro_spf_processed.dta", clear		
preserve
foreach x in i g u{

	* average uncertainty
	bys t target: egen ubar_beta_`x'=mean(variance_beta_`x')

	**** Figure A.1: Average ex-ante uncertainty based on beta distributions
	if "`x'"=="i"{
		local f 0
		local t 0.5
		local b 0.1
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f 0
		local t 0.7
		local b 0.1
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 0
		local t 0.6
		local b 0.1
		local color "dknavy"
		local description "Unemployment"
	}
	twoway (scatter ubar_beta_`x' target_year_`x' if h>1&h<8, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) msymbol(smx) mcolor(/*`color'*/gs10)) (scatter ubar_beta_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter ubar_beta_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\euro_ubar_beta_`x'.pdf", replace	
	
}
restore

**** Analysis of variance misalignment based on beta distributions 
use "Processed\euro_spf_processed.dta", clear		
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is close to zero)
	drop if nbins_`x'==1
	
	**** Variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_beta_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/var_mean_`x'	
	
	**** Figures A.2-A.3: Variance misalignment in the SPF data based on beta distributions (decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 8
		local b 2
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 24
		local b 4
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 10
		local b 2
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_m5_beta.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\euro_ratio_`x'_any_beta.pdf", replace
	
	restore
}

**** Horizon-specific estimates based on variances from beta distributions
use "Processed\euro_spf_processed.dta", clear	
foreach x in variance_beta{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_variance\Table_euro_`x'_`v'.xml"
	}
}
foreach x in i g u{
	foreach h in 8 7 6 5 4 3 2 1{
	
		preserve
		keep if h==`h'
		drop t
		egen t=group(fct_year fct_quarter)
		xtset fct_s t
		qui sum h
		local h=r(mean)
		
		**** rule of thumb for bandwidth selection
		qui sum t 
		local bw=round(4*(r(max)/100)^(2/9))
		
		**** time-fixed effects  
		qui tab t, gen(t_)
		
		foreach v in m5 m10 any most all{
		
			**** Fraction of model-based forecasters
			qui sum bin_`v'_`x'
			local bfrac=100*r(mean)
		
			**** variances
			cap noisily: qui reg variance_beta_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_beta_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_euro_variance_beta_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

		}
		restore
	}
}
foreach x in variance_beta{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_variance\Table_euro_`x'_`v'.txt"
	}
}

**** Figure A.6: Average deviations in the variances from beta distributions reported by rounders and non-rounders 
preserve
foreach x in variance_beta{
	foreach m in any most all m5 m10{
		if "`x'"=="variance_beta"&"`m'"=="any"|"`x'"=="variance_beta"&"`m'"=="m5"{
			local y "variance"
			local p 1
			local f 0
			local b 1
			local t 2
		}
		if "`x'"=="variance_beta"&"`m'"=="most"|"`x'"=="variance_beta"&"`m'"=="all"|"`x'"=="variance_beta"&"`m'"=="m10"{
			local y "variance"
			local p 1
			local f -1
			local b 1
			local t 2
		}
		
		xmluse "Tables\Tables_`y'\Table_euro_`x'_`m'", clear cells(B6:Y11)
		drop in 2 
		drop in 3
		drop in 4
		foreach v of varlist var10-var17{
			forvalues i=1(1)1{
				local j=`i'+1
				replace `v'=`v'[`j'] in `i'
			}
		}
		foreach v of varlist var18-var25{
			forvalues i=1(1)1{
				local j=`i'+2
				replace `v'=`v'[`j'] in `i'
			}
		}
		drop in 2/3
		gen i=1
		reshape long var, i(i) j(j)
		gen variable="inflation"
		replace variable="growth" if j>=10&j<=17
		replace variable="unemployment" if j>=18&j<=25
		drop i j
		replace var=subinstr(var, "*", "",.)
		destring var, replace
		seq h, f(8) t(1) b(1)
		twoway (line var h if variable=="inflation", title("") ytitle("{&beta}{subscript:h}", orientation(horizontal)) xtitle("") xscale(reverse) xtick(1(1)8) xlabel(1(1)8, labsize(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) lcolor(red) lwidth(medthick) plotr(m(zero)) legend(title("D{superscript:`m'}", size(medium)) order(0) region(lstyle(none)) position(`p') ring(0))) (scatter var h if variable=="inflation", mcolor(red) msymbol(diamond)) (line var h if variable=="growth", lcolor(dkgreen) lwidth(medthick) lpattern(longdash)) (scatter var h if variable=="growth", mcolor(dkgreen) msymbol(diamond)) (line var h if variable=="unemployment", lcolor(dknavy) lwidth(medthick) lpattern(shortdash)) (scatter var h if variable=="unemployment", mcolor(dknavy) msymbol(diamond))
		graph export "Figures\euro_`x'_`m'.pdf", replace
		
	}
}
restore

********************************************************
******** FED Survey of Professional Forecasters ********
********************************************************
use "Processed\usa_spf_processed.dta", clear

******** Section 3: Data ********

**** share of financial service providers, non-financial services providers and others
tab industry, gen(sector)
bys t: egen no=count(industry)
bys t: egen fin=total(sector1)
bys t: egen res=total(sector2)
bys t: egen oth=total(sector3)
gen fin_share=fin/no
gen res_share=res/no
gen oth_share=oth/no
sum *share
drop sector* no fin* res* oth*

**** Table II: Number of density forecasts provided by SPF participants
foreach x in i g u{
	count if variance_`x'!=.
	local sum=r(N)
	cap noisily: logout, save("Tables\Table_size") excel replace auto(2) dec(2): bys h: count if variance_`x'!=.
	preserve
	xmluse "Tables\Table_size.xml", clear cells(A3:A17)
	drop if var1=="->"
	destring var1, replace
	gen i=1
	gen h=_n
	reshape wide var1, i(i) j(h)
	drop i
	order *8 *7 *6 *5 *4 *3 *2 *1
	gen sum=`sum'
	listtex _all using "Tables\Table_size_fed_`x'.tex", replace rstyle(tabular)
	cap noisily: erase "Tables\Table_size.xml"
	cap noisily: erase "Tables\Table_size.txt"
	restore
}

**** total number of forecasters in common sample
preserve
duplicates drop fct_s, force
count
restore

**** number of forecasters in first and last survey round
inspect fct_s if t==1
inspect fct_s if t==76

**** number of forecasters per survey round
levelsof t, local(tlist)
foreach t of local tlist{
	preserve
	qui keep if t==`t'
	qui duplicates drop fct_s, force
	count if t==`t'
	restore
}

**** share of histograms that assign 100% probability to a single bin
tab nbins_i
tab nbins_g
tab nbins_u

**** Figures with actuals, consensus forecasts and average uncertainties for each forecast horizon
preserve
foreach x in i g u{

	**** Figure 3: Realizations and consensus forecasts from the SPF
	if "`x'"=="i"{
		local f 0
		local t 4
		local b 1
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f -5
		local t 6
		local b 1
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 4
		local t 13
		local b 1
		local color "dknavy"
		local description "Unemployment"
	}
	sort target_year_`x'
	twoway (line fr_`x' cr_`x' target_year_`x', title("") ytitle("Percentage points", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(7) ring(0)) plotr(m(zero)) lwidth(medthick medthick) lcolor(black black) lpattern(solid shortdash)) (scatter point_avg_`x' target_year_`x' if h>1&h<8, msymbol(smx) mcolor(/*`color'*/gs10)) (scatter point_avg_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter point_avg_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\usa_actuals_`x'.pdf", replace	
	
	**** Figure 4: Average ex-ante uncertainty
	if "`x'"=="i"{
		local f 0
		local t 1.2
		local b 0.2
	}
	if "`x'"=="g"{
		local f 0
		local t 2
		local b 0.5
	}
	if "`x'"=="u"{
		local f 0
		local t 0.6
		local b 0.1
	}
	twoway (scatter ubar_`x' target_year_`x' if h>1&h<8, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) msymbol(smx) mcolor(/*`color'*/gs10)) (scatter ubar_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter ubar_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\usa_ubar_`x'.pdf", replace	
	
}
restore

**** break in ex-ante inflation uncertainty before and after bin adjustment in 2014Q1 (t=61)
sum variance_i if t<=60
sum variance_i if t>=61

**** average number of bins used before and after bin adjustment in 2014Q1 (t=61)
sum nbins_i if t<=60
sum nbins_i if t>=61

**** average number of bins and ex-ante uncertainty (quarter-to-quarter)
levelsof t, local(tlist)
foreach t of local tlist{
preserve
	qui keep if t==`t'
	qui sum nbins_i if t==`t'
	local nbins=r(mean)
	qui sum variance_i if t==`t'
	local variance=r(mean)
	dis "In "fct_period[1] ", the average numer of bins is "`nbins' " and average ex-ante uncertainty is" `variance'
	restore
}

**** average ex-ante uncertainty (quarter-to-quarter / rounders vs. non-rounders)
preserve
egen avg_variance_i=mean(variance_i), by(t)
egen avg_variance_i_non=mean(variance_i) if bin_m5_i==1, by(t)
egen avg_variance_i_rou=mean(variance_i) if bin_m5_i==0, by(t)
line avg_variance_i avg_variance_i_non avg_variance_i_rou t
restore

**** average number of bins (quarter-to-quarter / rounders vs. non-rounders)
preserve
egen avg_nbins_i=mean(nbins_i), by(t)
egen avg_nbins_i_non=mean(nbins_i) if bin_m5_i==1, by(t)
egen avg_nbins_i_rou=mean(nbins_i) if bin_m5_i==0, by(t)
line avg_nbins_i avg_nbins_i_non avg_nbins_i_rou t
restore

******** Section 5.1: Rounders and non-rounders in the SPF data ********

**** Figure 5: Share of rounded histograms (integer-based categorization)
foreach x in i g u{
	if "`x'"=="i"{
		local color red
		local description "Inflation"
	}
	if "`x'"=="g"{
		local color dkgreen
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local color dknavy
		local description "Unemployment"
	}
	preserve
	forvalues tau=1(1)10{
		replace bin_m`tau'_`x'=100*(1-bin_m`tau'_`x')
	}
	graph bar (mean) bin_m1_`x' bin_m2_`x' bin_m3_`x' bin_m4_`x' bin_m5_`x' bin_m6_`x' bin_m7_`x' bin_m8_`x' bin_m9_`x' bin_m10_`x', b1title(" ") text(-12 50 "{&tau}") showyvars yvaroptions(relabel(1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6" 7 "7" 8 "8" 9 "9" 10 "10") label(labsize(vsmall))) bargap(10) title("") ytitle("%", orientation(horizontal) size(small)) ytick(105, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(1) ring(0)) plotr(m(zero)) bar(1, color(`color')) bar(2, color(`color')) bar(3, color(`color')) bar(4, color(`color')) bar(5, color(`color')) bar(6, color(`color')) bar(7, color(`color')) bar(8, color(`color')) bar(9, color(`color')) bar(10, color(`color')) blabel(bar, format(%9.2f) size(vsmall))	
	graph export "Figures\usa_tau_`x'.pdf", replace
	restore
}	

**** correlations across categorizations and variables
pwcorr bin_any_* bin_m5_*, sig star(0.05)

**** for each variable, calculate the share of observations unanimously classified by both categorizations
foreach x in i g u{
	dis "Variable = `x' "
	
	* count the total number of classified histograms
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.
	local total=r(N)
	
	* number and share of histograms unanimously classified as non-rounders across categorizations
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==1&bin_m5_`x'==1
	local non_unanimous=r(N)
	dis "Share of histograms unanimously classified as non-rounders across categorizations = "`non_unanimous'/`total'
	
	* number and share histograms unanimously classified as rounders across categorizations
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==0&bin_m5_`x'==0
	local rou_unanimous=r(N)
	dis "Share of histograms unanimously classified as rounders across categorizations = "`rou_unanimous'/`total'
	
	* share of unanimously classified histograms across categorizations
	dis "Share of unanimously classified histograms across categorizations = "(`non_unanimous'+`rou_unanimous')/`total'
	
	* number and share of histograms classified as rounders by any but as non-rounders by m5
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==0&bin_m5_`x'==1
	local not_unanimous_a=r(N)
	dis "Share of histograms classified as rounders by any but as non-rounders by m5 = "`not_unanimous_a'/`total'
	
	* number and share of histograms classified as non-rounders by any but as rounders by m5
	qui count if bin_any_`x'!=.&bin_m5_`x'!=.&bin_any_`x'==1&bin_m5_`x'==0
	local not_unanimous_b=r(N)
	dis "Share of histograms classified as non-rounders by any but as rounders by m5 = "`not_unanimous_b'/`total'
	
	* share of differently classified histograms across categorizations
	dis "Share of differently classified histograms across categorizations = "(`not_unanimous_a'+`not_unanimous_b')/`total'
	
	dis ""
}

**** for each categorization, calculate the share of observations unanimously classified across all three variables
foreach v in any m5{
	dis "Categorization = `v' "

	* count the total number of classified histograms
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.
	local total=r(N)
	
	* number and share of histograms unanimously classified as non-rounders across variables
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.&bin_`v'_i==1&bin_`v'_g==1&bin_`v'_u==1
	local non_unanimous=r(N)
	dis "Share of histograms unanimously classified as non-rounders across variables = "`non_unanimous'/`total'
	
	* number and share of histograms unanimously classified as rounders across variables
	qui count if bin_`v'_i!=.&bin_`v'_g!=.&bin_`v'_u!=.&bin_`v'_i==0&bin_`v'_g==0&bin_`v'_u==0
	local rou_unanimous=r(N)
	dis "Share of histograms unanimously classified as rounders across variables = "`rou_unanimous'/`total'
	
	* share of unanimously classified histograms across variables
	dis "Share of unanimously classified histograms across variables for `v' = "(`non_unanimous'+`rou_unanimous')/`total'
	
	dis ""
}

**** Table III: Share of non-rounded observations across horizons
foreach x in i g u{
	bys h: sum bin_any_`x' bin_most_`x' bin_all_`x' bin_m5_`x' bin_m10_`x'
	foreach v in any most all m5 m10{
		cap noisily: logout, save("Tables\Table_share") excel replace auto(4) dec(4): bys h: tabstat bin_`v'_`x'
		preserve
		xmluse "Tables\Table_share.xml", clear cells(B5:B40)
		drop if var2==""|var2=="h"|var2=="mean"
		gen i=1
		gen h=_n
		destring var2, replace
		replace var2=100*var2
		format var2 %5.2f
		reshape wide var2, i(i) j(h)
		drop i
		order *8 *7 *6 *5 *4 *3 *2 *1
		listtex _all using "Tables\Table_share_fed_`x'_`v'.tex", replace rstyle(tabular)
		cap noisily: erase "Tables\Table_share.xml"
		cap noisily: erase "Tables\Table_share.txt"
		restore
	}
}	

**** Figure 6: Time-variation in the share of non-rounders
foreach x in i g u{
	bys t: egen share_any_`x'=mean(bin_any_`x')
	replace share_any_`x'=100*share_any_`x'
	bys t: egen share_m5_`x'=mean(bin_m5_`x')
	replace share_m5_`x'=100*share_m5_`x'
}
qui sum t
local max=r(max)
line share_any_i share_any_g share_any_u t, title("") ytitle("%", orientation(horizontal) size(small)) xtitle("") xtick(1(1)`max') xlabel(5 "2000" 21 "2004" 37 "2008" 53 "2012" 69 "2016", labsize(small)) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) lcolor(red dkgreen dknavy) lwidth(medthick medthick medthick) lpattern(solid longdash shortdash) plotr(m(zero)) ytick(0(10)50) ylabel(0(10)50, angle(horizontal) labsize(small)) 
graph export "Figures\usa_shares_any.pdf", replace
line share_m5_i share_m5_g share_m5_u t, title("") ytitle("%", orientation(horizontal) size(small)) xtitle("") xtick(1(1)`max') xlabel(5 "2000" 21 "2004" 37 "2008" 53 "2012" 69 "2016", labsize(small)) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) lcolor(red dkgreen dknavy) lwidth(medthick medthick medthick) lpattern(solid longdash shortdash) plotr(m(zero)) ytick(0(10)50) ylabel(0(10)50, angle(horizontal) labsize(small)) 
graph export "Figures\usa_shares_m5.pdf", replace
* comparison to Table III:
bys h: sum share*
	
******** Section 5.2: Analysis of variance misalignment ********
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is zero)
	drop if nbins_`x'==1
	
	**** exclude forecaster 563 
	*scatter sqerr_i variance_i h if fct_s == 563
	drop if fct_source==563
	
	**** Variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/var_mean_`x' 	

	**** Figures 7 and 8: Variance misalignment in the SPF data (decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 2
		local b 1
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 4
		local b 1
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 3
		local b 1
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_m5.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_any.pdf", replace
	
	restore
}

**** Figures 9 and 10: Average number of bins used / average ex-ante variances reported by rounders and non-rounders
preserve
keep nbins* variance* bin_any* bin_m5*
drop *beta*
gen i=_n
reshape long nbins_ variance_ bin_any_ bin_m5_, i(i) j(var) string
encode var, gen(v)
replace v=0 if v==2
graph bar (mean) nbins_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_any_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(11, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\usa_avg_nbins_any.pdf", replace
graph bar (mean) nbins_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_m5_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(11, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\usa_avg_nbins_m5.pdf", replace
graph bar (mean) variance_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_any_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(2.2, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:any}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\usa_avg_variance_any.pdf", replace
graph bar (mean) variance_, over(var, sort(v) gap(10) label(labsize(vsmall)) relabel(2 "Growth" 1 "Inflation" 3 "Unemployment")) asyvar bar(2, color(red)) bar(1, color(dkgreen)) bar(3, color(dknavy)) over(bin_m5_, gap(80) relabel(1 "Rounders" 2 "Non-rounders") label(labsize(small))) title("") ytitle("") ytick(2.2, noticks) ylabel(none) scale(1.5) scheme(s1color) legend(title("D{superscript:m5}", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) blabel(total, format(%9.2f)) 
graph export "Figures\usa_avg_variance_m5.pdf", replace
restore

**** Figure 11: Average uncertainty of rounders and non-rounders for one-year-ahead predictions 
preserve
keep if fct_quarter==1&h==4
sort t
foreach x in i g u{
	if "`x'"=="i"{
		local f 0
		local t 2
		local b 1
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f 0
		local t 3
		local b 1
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 0
		local t 0.6
		local b 0.1
		local color "dknavy"
		local description "Unemployment"
	}
	line ubar_`x'_rou ubar_`x'_non fct_year, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(7) ring(0)) plotr(m(zero)) lcolor(`color' `color') lpattern(solid longdash_dot) lwidth(medthick medthick)
	graph export "Figures\usa_ubar_`x'_m5_both.pdf", replace	
}
restore

******** Section 5.3: Differences in histogram characteristics ********	
foreach x in nbins variance abserr sqerr qps rps skew kurt{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_`x'\Table_usa_`x'_`v'.xml"
		cap noisily: erase "Tables\Tables_`x'\Table_usa_`x'_wide_`v'.xml"
	}
}
foreach x in i g u{
	foreach h in 8 7 6 5 4 3 2 1{
	
		preserve
		keep if h==`h'
		drop t
		egen t=group(fct_year fct_quarter)
		xtset fct_s t
		qui sum h
		local h=r(mean)
		
		**** rule of thumb for bandwidth selection
		qui sum t 
		local bw=round(4*(r(max)/100)^(2/9))
		
		**** time-fixed effects  
		qui tab t, gen(t_)
		
		foreach v in m5 m10 any most all{
		
			**** Fraction of model-based forecasters
			qui sum bin_`v'_`x'
			local bfrac=100*r(mean)
		
			**** number of bins
			cap noisily: qui reg nbins_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 nbins_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_nbins\Table_usa_nbins_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** variances
			cap noisily: qui reg variance_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_usa_variance_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

			**** absolute forecast error
			cap noisily: qui reg abserr_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 abserr_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_abserr\Table_usa_abserr_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
					
			**** squared forecast error
			cap noisily: qui reg sqerr_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 sqerr_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_sqerr\Table_usa_sqerr_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			******** additional histogram characteristics (not included in the main article) ********
			
			**** quadratic probability score
			cap noisily: qui reg qps_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 qps_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_qps\Table_usa_qps_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** ranked probability score
			cap noisily: qui reg rps_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 rps_`x' bin_`v'_`x'  t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_rps\Table_usa_rps_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
		
			**** skewness
			cap noisily: qui reg skew_`x' bin_`v'_`x' t_* if skew_`x'>-50
			local r2=e(r2_a)
			cap noisily: qui newey2 skew_`x' bin_`v'_`x'  t_* if skew_`x'>-50, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_skew\Table_usa_skew_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** kurtosis
			cap noisily: qui reg kurt_`x' bin_`v'_`x' t_* if kurt_`x'<50
			local r2=e(r2_a)
			cap noisily: qui newey2 kurt_`x' bin_`v'_`x' t_* if kurt_`x'<50, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_kurt\Table_usa_kurt_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
						
			******** consider forecasters who use at least 4 bins (not included in the main article) ********

			**** number of bins
			cap noisily: qui reg nbins_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 nbins_`x' bin_`v'_`x' t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_nbins\Table_usa_nbins_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** variances
			cap noisily: qui reg variance_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_`x' bin_`v'_`x' t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_usa_variance_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

			**** absolute forecast error
			cap noisily: qui reg abserr_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 abserr_`x' bin_`v'_`x'  t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_abserr\Table_usa_abserr_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
			**** squared forecast error
			cap noisily: qui reg sqerr_`x' bin_`v'_`x' t_* if nbins_`x'>=4
			local r2=e(r2_a)
			cap noisily: qui newey2 sqerr_`x' bin_`v'_`x'  t_* if nbins_`x'>=4, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_sqerr\Table_usa_sqerr_wide_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)
			
		}
		restore
	}
}
foreach x in nbins variance abserr sqerr qps rps skew kurt{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_`x'\Table_usa_`x'_`v'.txt"
		cap noisily: erase "Tables\Tables_`x'\Table_usa_`x'_wide_`v'.txt"
	}
}

**** Figures 12-13: Average deviations in histogram characteristics of rounders and non-rounders (plus Figures A.4-A.5 and A.7-A.8 from Appendix and Figures 7-12 from Supplement)
preserve
foreach x in nbins variance abserr sqerr qps rps skew kurt nbins_wide variance_wide abserr_wide sqerr_wide{

	if "`x'"=="nbins_wide"{
		local y "nbins"
		local p 1
		local f 0
		local b 1
		local t 7
	}
	if "`x'"=="variance_wide"{
		local y "variance"
		local p 1
		local f -1
		local b 1
		local t 2
	}
	if "`x'"=="abserr_wide"{
		local y "abserr"
		local p 1
		local f -0.2
		local b 0.2
		local t 0.6
	}
	if "`x'"=="sqerr_wide"{
		local y "sqerr"
		local p 1
		local f -1
		local b 1
		local t 2
	}
	if "`x'"=="qps"{
		local y "qps"
		local p 11
		local f -0.4
		local b 0.2
		local t 0.4
	}
	if "`x'"=="rps"{
		local y "rps"
		local p 1
		local f -0.4
		local b 0.2
		local t 0.8
	}
	if "`x'"=="skew"{
		local y "skew"
		local p 7
		local f -5
		local b 1
		local t 5
	}
	if "`x'"=="kurt"{
		local y "kurt"
		local p 11
		local f -2
		local b 2
		local t 8
	}
	foreach m in any most all m5 m10{
	
		if "`x'"=="nbins"&"`m'"=="any"|"`x'"=="nbins"&"`m'"=="m5"{
			local y "nbins"
			local p 7
			local f 0
			local b 2
			local t 6
		}
		if "`x'"=="nbins"&"`m'"=="most"|"`x'"=="nbins"&"`m'"=="all"|"`x'"=="nbins"&"`m'"=="m10"{
			local y "nbins"
			local p 7
			local f 0
			local b 2
			local t 8
		}
		if "`x'"=="variance"&"`m'"=="any"|"`x'"=="variance"&"`m'"=="m5"{
			local y "variance"
			local p 1
			local f 0
			local b 1
			local t 2
		}
		if "`x'"=="variance"&"`m'"=="most"|"`x'"=="variance"&"`m'"=="all"|"`x'"=="variance"&"`m'"=="m10"{
			local y "variance"
			local p 1
			local f -1
			local b 1
			local t 2
		}
		if "`x'"=="abserr"&"`m'"=="any"|"`x'"=="abserr"&"`m'"=="m5"{
			local y "abserr"
			local p 1
			local f -0.4
			local b 0.2
			local t 0.6
		}
		if "`x'"=="abserr"&"`m'"=="most"|"`x'"=="abserr"&"`m'"=="all"|"`x'"=="abserr"&"`m'"=="m10"{
			local y "abserr"
			local p 1
			local f -0.4
			local b 0.2
			local t 0.6
		}
		if "`x'"=="sqerr"&"`m'"=="any"|"`x'"=="sqerr"&"`m'"=="m5"{
			local y "sqerr"
			local p 1
			local f -0.5
			local b 0.5
			local t 1.5		
		}
		if "`x'"=="sqerr"&"`m'"=="most"|"`x'"=="sqerr"&"`m'"=="all"|"`x'"=="sqerr"&"`m'"=="m10"{
			local y "sqerr"
			local p 1
			local f -0.5
			local b 0.5
			local t 1.5	
		}
	
		xmluse "Tables\Tables_`y'\Table_usa_`x'_`m'", clear cells(B6:Y11)
		drop in 2 
		drop in 3
		drop in 4
		foreach v of varlist var10-var17{
			forvalues i=1(1)1{
				local j=`i'+1
				replace `v'=`v'[`j'] in `i'
			}
		}
		foreach v of varlist var18-var25{
			forvalues i=1(1)1{
				local j=`i'+2
				replace `v'=`v'[`j'] in `i'
			}
		}
		drop in 2/3
		gen i=1
		reshape long var, i(i) j(j)
		gen variable="inflation"
		replace variable="growth" if j>=10&j<=17
		replace variable="unemployment" if j>=18&j<=25
		drop i j
		replace var=subinstr(var, "*", "",.)
		destring var, replace
		seq h, f(8) t(1) b(1)
		twoway (line var h if variable=="inflation", title("") ytitle("{&beta}{subscript:h}", orientation(horizontal)) xtitle("") xscale(reverse) xtick(1(1)8) xlabel(1(1)8, labsize(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) lcolor(red) lwidth(medthick) plotr(m(zero)) legend(title("D{superscript:`m'}", size(medium)) order(0) region(lstyle(none)) position(`p') ring(0))) (scatter var h if variable=="inflation", mcolor(red) msymbol(diamond)) (line var h if variable=="growth", lcolor(dkgreen) lwidth(medthick) lpattern(longdash)) (scatter var h if variable=="growth", mcolor(dkgreen) msymbol(diamond)) (line var h if variable=="unemployment", lcolor(dknavy) lwidth(medthick) lpattern(shortdash)) (scatter var h if variable=="unemployment", mcolor(dknavy) msymbol(diamond))
		graph export "Figures\usa_`x'_`m'.pdf", replace
		
	}
}
restore

******** Section 6.1: Variance misalignment and the width of histogram bins ********
use "Processed\usa_spf_processed.dta", clear	
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is zero)
	drop if nbins_`x'==1
	
	**** exclude forecaster 563
	*scatter sqerr_i variance_i h if fct_s == 563
	drop if fct_source==563
	
	**** Variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/var_mean_`x'
	
	**** Figures XX and 15: Adjusted variance misalignment in the SPF data (decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 2
		local b 1
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 5
		local b 1
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 3
		local b 1
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_m5_adj.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_any_adj.pdf", replace
	
	restore
}

**************************
******** Appendix ********
**************************

**** Table A.I: Industry classification and non-rounders in the FED-SPF
tab industry, gen(sector)
foreach x in i g u{
	pwcorr sector* bin_any_`x' bin_most_`x' bin_all_`x' bin_m5_`x' bin_m10_`x'
	foreach v in any most all m5 m10{
		cap noisily: logout, save("Tables\Table_corr_industry") excel replace auto(2) dec(2): corr bin_`v'_`x' sector*
		preserve
		xmluse "Tables\Table_corr_industry.xml", clear cells(B6:B8)
		gen i=1
		gen h=_n
		reshape wide var2, i(i) j(h)
		drop i
		listtex _all using "Tables\Table_corr_industry_fed_`x'_`v'.tex", replace rstyle(tabular)
		cap noisily: erase "Tables\Table_corr_industry.xml"
		cap noisily: erase "Tables\Table_corr_industry.txt"
		restore
	}
}	

**** Table A.II: Pooled MSE for the ECB-SPF and the FED-SPF
use "Processed\usa_spf_processed.dta", clear	
* Full sample MSE
sum sqerr*
* Excluding 2009
sum sqerr* if target_year_g!=2009

**** Tables A.V-A.VII: Pooled regressions for average deviations of (inflation/real GDP growth/unemployment) histogram characteristics in the FED-SPF
use "Processed\usa_spf_processed.dta", clear

* FE dummies
tab h, gen(h_)
tab fct_period, gen(t_)
tab fct_source, gen(i_)

* bandwidth selection
sum t
local bw=round(4*(r(max)/100)^(2/9))
dis `bw'

* panel structure
drop t
egen t=group(fct_year fct_quarter h)
xtset fct_s t

* Pooled regressions
foreach x in i g u{
	cap noisily: erase "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.xml"
	preserve
	
	* interactions of horizon-FE and rounding dummy
	drop h_1
	forvalues h=2(1)8{
		gen ia_`h'=bin_m5_`x'*h_`h'
	}
	
	* loop over histogram characteristics
	foreach y in nbins variance variance_beta abserr sqerr{
	
		* no forecaster-FE
		qui reg `y'_`x' bin_m5_`x' ia_* h_* t_*
		local r2a=e(r2_a)
		qui newey2 `y'_`x' bin_m5_`x' ia_* h_* t_*, lag(`bw') force
		dis "DV: `y'_`x', no forecaster-FE"
		test bin_m5_`x' h_2 h_3 h_4 h_5 h_6 h_7 h_8 ia_2 ia_3 ia_4 ia_5 ia_6 ia_7 ia_8 
		test (ia_2=ia_3)
		test (ia_3=ia_4)
		test (ia_4=ia_5)
		test (ia_5=ia_6)
		test (ia_6=ia_7)
		test (ia_7=ia_8)
		cap noisily: outreg2 using "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.xml", excel append auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(Adj. R2, `r2a') addtext(Horizon-FE, Yes, Time-FE, Yes, Forecaster-FE, No) title("Pooled regressions for differences in histogram characteristics") drop(h_* t_* i_* o.t_* o.i_*) noaster
		
		* including forecaster-FE
		qui reg `y'_`x' bin_m5_`x' ia_* h_* t_* i_*
		local r2a=e(r2_a)
		qui newey2 `y'_`x' bin_m5_`x' ia_* h_* t_* i_*, lag(`bw') force
		qui test bin_m5_`x' h_2 h_3 h_4 h_5 h_6 h_7 h_8 ia_2 ia_3 ia_4 ia_5 ia_6 ia_7 ia_8
		dis "DV: `y'_`x', no forecaster-FE"
		test bin_m5_`x' h_2 h_3 h_4 h_5 h_6 h_7 h_8 ia_2 ia_3 ia_4 ia_5 ia_6 ia_7 ia_8
		test (ia_2=ia_3)
		test (ia_3=ia_4)
		test (ia_4=ia_5)
		test (ia_5=ia_6)
		test (ia_6=ia_7)
		test (ia_7=ia_8)
		cap noisily: outreg2 using "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.xml", excel append auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(Adj. R2, `r2a') addtext(Horizon-FE, Yes, Time-FE, Yes, Forecaster-FE, Yes) title("Pooled regressions for differences in histogram characteristics") drop(h_* t_* i_* o.t_* o.i_*) noaster
	
	}
	restore
	cap noisily: erase "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.txt"
}

**** Latex table
preserve
foreach x in i g u{
	cap noisily: xmluse "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.xml", clear cells(A6:K29)
	replace var1=" $ D_{i,t,h}^{\text{m}5}$" if var1=="bin_m5_`x'"
	forvalues j=2(1)8{
		replace var1=" $ D_{i,t,h}^{\text{m}5} \times D_{i,t,h}^{h=`j'}$" if var1=="ia_`j'"
	}
	replace var1=" $ \bar{R}^2$" if var1=="Adj. R2"
	cap noisily: listtex _all using "Tables/Tables_pooled/Table_usa_panel_regressions_`x'.tex", replace rstyle(tabular)
}	
restore

**** Figures A.1: Average ex-ante uncertainty based on beta distributions
use "Processed\usa_spf_processed.dta", clear
preserve
foreach x in i g u{

	* average uncertainty
	bys t target: egen ubar_beta_`x'=mean(variance_beta_`x')
	
	**** Figure A.1: Average ex-ante uncertainty based on beta distributions
	if "`x'"=="i"{
		local f 0
		local t 1.2
		local b 0.2
		local color "red"
		local description "Inflation"
	}
	if "`x'"=="g"{
		local f 0
		local t 2
		local b 0.5
		local color "dkgreen"
		local description "GDP growth"
	}
	if "`x'"=="u"{
		local f 0
		local t 0.6
		local b 0.1
		local color "dknavy"
		local description "Unemployment"
	}
	twoway (scatter ubar_beta_`x' target_year_`x' if h>1&h<8, title("") ytitle("") ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(2000(1)2017) xlabel(2000 "2000" 2004 "2004" 2008 "2008" 2012 "2012" 2016 "2016", labsize(vsmall)) scale(1.5) scheme(s1color) legend(title("`description'", size(medium)) order(0) region(lstyle(none)) position(11) ring(0)) plotr(m(zero)) msymbol(smx) mcolor(/*`color'*/gs10)) (scatter ubar_beta_`x' target_year_`x' if h==1, mlcolor(black) mfcolor(`color')) (scatter ubar_beta_`x' target_year_`x' if h==8, mlcolor(black) mfcolor(`color') msymbol(triangle))
	graph export "Figures\usa_ubar_beta_`x'.pdf", replace	
	
}
restore

**** Analysis of variance misalignment based on beta distributions 
use "Processed\usa_spf_processed.dta", clear
foreach x in i g u{
	preserve
	
	**** exclude all forecasts that only use one bin (their uncertainty is close to zero)
	drop if nbins_`x'==1
	
	**** exclude forecaster 563  
	*scatter sqerr_i variance_i h if fct_s == 563
	drop if fct_source==563
	
	**** Variance misalignment in the SPF data (decimal- and integer-based categorization)
	egen mse_`x'=mean(sqerr_`x') if point_imp_`x'!=., by(fct_s h)
	egen var_mean_`x'=mean(variance_beta_`x') if point_imp_`x'!=., by(fct_s h)
	gen m_ind_`x'=mse_`x'/var_mean_`x' 	

	**** Figures A.2-A.3: Variance misalignment in the SPF data based on beta distributions (decimal- and integer-based categorization)
	bys h: egen m_`x'_all=mean(m_ind_`x')
	bys h: egen m_`x'_rou_m5=mean(m_ind_`x') if bin_m5_`x'==0
	bys h: egen m_`x'_non_m5=mean(m_ind_`x') if bin_m5_`x'==1
	bys h: egen m_`x'_rou_any=mean(m_ind_`x') if bin_any_`x'==0
	bys h: egen m_`x'_non_any=mean(m_ind_`x') if bin_any_`x'==1
	if "`x'"=="i"{
		local f 0
		local t 2
		local b 1
		local color "red"
	}
	if "`x'"=="g"{
		local f 0
		local t 6
		local b 1
		local color "dkgreen"	
	}
	if "`x'"=="u"{
		local f 0
		local t 5
		local b 1
		local color "dknavy"
	}
	gen H=-h
	twoway connected m_`x'_all m_`x'_rou_m5 m_`x'_non_m5 H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_m5_beta.pdf", replace
	twoway connected m_`x'_all m_`x'_rou_any m_`x'_non_any H, lcolor(`color' `color' `color') lpattern(solid longdash shortdash) mcolor(`color' `color' `color') msymbol(X triangle square) title("") ytitle("Misalignment ratio", size(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(vsmall)) xtitle("") xtick(-8(1)-1) xlabel(-8 "8" -7 "7" -6 "6" -5 "5" -4 "4" -3 "3" -2 "2" -1 "1", labsize(vsmall)) scale(1.5) scheme(s1color) plotr(m(zero)) yline(1, lcolor(black) lpattern(longdash)) legend(order(1 2 3) label(1 "full sample") label(2 "rounders") label(3 "non-rounders") cols(1) region(lstyle(none)) position(1) ring(0))
	graph export "Figures\usa_ratio_`x'_any_beta.pdf", replace
	
	restore
}

**** Horizon-specific estimates based on variances from beta distributions
use "Processed\usa_spf_processed.dta", clear
foreach x in variance_beta{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_variance\Table_usa_`x'_`v'.xml"
	}
}
foreach x in i g u{
	foreach h in 8 7 6 5 4 3 2 1{
	
		preserve
		keep if h==`h'
		drop t
		egen t=group(fct_year fct_quarter)
		xtset fct_s t
		qui sum h
		local h=r(mean)
		
		**** rule of thumb for bandwidth selection
		qui sum t 
		local bw=round(4*(r(max)/100)^(2/9))
		
		**** time-fixed effects  
		qui tab t, gen(t_)
		
		foreach v in m5 m10 any most all{
		
			**** Fraction of model-based forecasters
			qui sum bin_`v'_`x'
			local bfrac=100*r(mean)
		
			**** variances
			cap noisily: qui reg variance_beta_`x' bin_`v'_`x' t_*
			local r2=e(r2_a)
			cap noisily: qui newey2 variance_beta_`x' bin_`v'_`x' t_*, lag(`bw') force
			cap noisily: outreg2 using "Tables\Tables_variance\Table_usa_variance_beta_`v'", append excel auto(2) bdec(2) sdec(2) rdec(2) adec(2) addstat(R-squared, `r2', Share non-rounders, `bfrac') ctitle("`x', h=`h'") drop(t_* o.t_*) addtext(TFE, yes) alpha(0.05) symbol(*)

		}
		restore
	}
}
foreach x in variance_beta{
	foreach v in m5 m10 any most all{
		cap noisily: erase "Tables\Tables_variance\Table_usa_`x'_`v'.txt"
	}
}

**** Figure A.6: Average deviations in the variances from beta distributions reported by rounders and non-rounders 
preserve
foreach x in variance_beta{
	foreach m in any most all m5 m10{
		if "`x'"=="variance_beta"&"`m'"=="any"|"`x'"=="variance_beta"&"`m'"=="m5"{
			local y "variance"
			local p 1
			local f 0
			local b 1
			local t 2
		}
		if "`x'"=="variance_beta"&"`m'"=="most"|"`x'"=="variance_beta"&"`m'"=="all"|"`x'"=="variance_beta"&"`m'"=="m10"{
			local y "variance"
			local p 1
			local f -1
			local b 1
			local t 2
		}
	
		xmluse "Tables\Tables_`y'\Table_usa_`x'_`m'", clear cells(B6:Y11)
		drop in 2 
		drop in 3
		drop in 4
		foreach v of varlist var10-var17{
			forvalues i=1(1)1{
				local j=`i'+1
				replace `v'=`v'[`j'] in `i'
			}
		}
		foreach v of varlist var18-var25{
			forvalues i=1(1)1{
				local j=`i'+2
				replace `v'=`v'[`j'] in `i'
			}
		}
		drop in 2/3
		gen i=1
		reshape long var, i(i) j(j)
		gen variable="inflation"
		replace variable="growth" if j>=10&j<=17
		replace variable="unemployment" if j>=18&j<=25
		drop i j
		replace var=subinstr(var, "*", "",.)
		destring var, replace
		seq h, f(8) t(1) b(1)
		twoway (line var h if variable=="inflation", title("") ytitle("{&beta}{subscript:h}", orientation(horizontal)) xtitle("") xscale(reverse) xtick(1(1)8) xlabel(1(1)8, labsize(small)) ytick(`f'(`b')`t') ylabel(`f'(`b')`t', angle(horizontal) labsize(small)) scale(1.5) scheme(s1color) lcolor(red) lwidth(medthick) plotr(m(zero)) legend(title("D{superscript:`m'}", size(medium)) order(0) region(lstyle(none)) position(`p') ring(0))) (scatter var h if variable=="inflation", mcolor(red) msymbol(diamond)) (line var h if variable=="growth", lcolor(dkgreen) lwidth(medthick) lpattern(longdash)) (scatter var h if variable=="growth", mcolor(dkgreen) msymbol(diamond)) (line var h if variable=="unemployment", lcolor(dknavy) lwidth(medthick) lpattern(shortdash)) (scatter var h if variable=="unemployment", mcolor(dknavy) msymbol(diamond))
		graph export "Figures\usa_`x'_`m'.pdf", replace
		
	}
}
restore

window manage close graph
